var group___math =
[
    [ "Ogre::Affine3", "class_ogre_1_1_affine3.html", [
      [ "Affine3", "class_ogre_1_1_affine3.html#a30b0a43638d438c54c335453a3bf4636", null ],
      [ "Affine3", "class_ogre_1_1_affine3.html#a5ce74f781c8c3ce99976c31fba9a6eb0", null ],
      [ "Affine3", "class_ogre_1_1_affine3.html#ad56cb358b997cb1ef2b156bbda26e1ec", null ],
      [ "Affine3", "class_ogre_1_1_affine3.html#a4f62949a39d5c9e1b6003e3bfbb7c2f2", null ],
      [ "Affine3", "class_ogre_1_1_affine3.html#a23c6bb6170cd619be269bec8ed434ef4", null ],
      [ "Affine3", "class_ogre_1_1_affine3.html#aff614a967fe24db7a8059be148f9c8a1", null ],
      [ "operator=", "class_ogre_1_1_affine3.html#afb3750f16d3cda4efac274773906b5e5", null ],
      [ "operator==", "class_ogre_1_1_affine3.html#ae0ff2f252c8642916d15316ff0e2107c", null ],
      [ "operator!=", "class_ogre_1_1_affine3.html#a44f73afce352e88d8b8463475baf6b5a", null ],
      [ "inverse", "class_ogre_1_1_affine3.html#aad8e3b12ac04a0229d5a2af84f358883", null ],
      [ "decomposition", "class_ogre_1_1_affine3.html#a2a72dd6d84a4f57a881f94de62bc8a34", null ],
      [ "operator const Matrix4 &", "class_ogre_1_1_affine3.html#a4cce7fb866e2a35fc2c425f897d03ca2", null ],
      [ "getTrans", "class_ogre_1_1_affine3.html#aa9ab6eb8ff75222d1154f14bdd3d2a8e", null ],
      [ "getTrans", "class_ogre_1_1_affine3.html#ae45c5a41dd3e6b752e406a5597a1990d", null ],
      [ "getScale", "class_ogre_1_1_affine3.html#a0ea806400969075b54313aed739cdce6", null ],
      [ "getScale", "class_ogre_1_1_affine3.html#a9fcc18e98ded8a18261e66f92fc2dfe8", null ],
      [ "ZERO", "class_ogre_1_1_affine3.html#a9a771b8258d88c5a37f58494de1b0597", null ],
      [ "IDENTITY", "class_ogre_1_1_affine3.html#af37f4f9d112151323e0f53d135c13612", null ]
    ] ],
    [ "Ogre::Angle", "class_ogre_1_1_angle.html", [
      [ "Angle", "class_ogre_1_1_angle.html#a2993f9aef3ffaa7b745813f11a511bdb", null ],
      [ "operator Radian", "group___math.html#gaf5f6b1190c20ab261874497f6bbb7dfd", null ],
      [ "operator Degree", "group___math.html#ga166c0b2a2264eac93345461f93005b6e", null ]
    ] ],
    [ "Ogre::AxisAlignedBox", "class_ogre_1_1_axis_aligned_box.html", [
      [ "Corners", "class_ogre_1_1_axis_aligned_box.html#a769c7e06e985a9f6d47cd5be57cef4d7", null ],
      [ "Extent", "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443e", [
        [ "EXTENT_NULL", "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443ea5046ce9384ab8647fb3c58e03d5446c9", null ],
        [ "EXTENT_FINITE", "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443eafa5a4b01ba1d49c7b3db966223bf6642", null ],
        [ "EXTENT_INFINITE", "class_ogre_1_1_axis_aligned_box.html#a49fc600cdfc76dfaba2613ce3af2443ea549926fd8188d52a8a579673de7b93a2", null ]
      ] ],
      [ "CornerEnum", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3", [
        [ "FAR_LEFT_BOTTOM", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3a2ba07c11671eb44dae2015d45a9fa861", null ],
        [ "FAR_LEFT_TOP", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3a805a552d90a29ea9fd8c247500dcd92e", null ],
        [ "FAR_RIGHT_TOP", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3a83ef287678d55680f7d26c0e1a0af88b", null ],
        [ "FAR_RIGHT_BOTTOM", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3a82a1588bb8174e562e0e21a3469cd428", null ],
        [ "NEAR_RIGHT_BOTTOM", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3a03c007f742ece84e634533dad5655289", null ],
        [ "NEAR_LEFT_BOTTOM", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3ad7af8f1d62fb0717955df915775bba40", null ],
        [ "NEAR_LEFT_TOP", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3ab6b3c127e0bec403f8b162153fa8977c", null ],
        [ "NEAR_RIGHT_TOP", "class_ogre_1_1_axis_aligned_box.html#a771c83dfb946e6d66c9ddf09fba7e5b3ab76a3b018615466de7e96bf65fed7696", null ]
      ] ],
      [ "AxisAlignedBox", "class_ogre_1_1_axis_aligned_box.html#a848fa65c291ef9f898a48c686c9a0444", null ],
      [ "AxisAlignedBox", "class_ogre_1_1_axis_aligned_box.html#a9abfa2f7b652f0418d6b5236cd18390e", null ],
      [ "AxisAlignedBox", "class_ogre_1_1_axis_aligned_box.html#a376f0d3333f8c5e84e679a981b2cc4dd", null ],
      [ "AxisAlignedBox", "class_ogre_1_1_axis_aligned_box.html#ac500b5c0c4b894d031e5c53357586358", null ],
      [ "getMinimum", "class_ogre_1_1_axis_aligned_box.html#ac33a45e9c52c720c900469d128be44d8", null ],
      [ "getMinimum", "class_ogre_1_1_axis_aligned_box.html#a44ec80e4e2245550381eeb88183143fd", null ],
      [ "getMaximum", "class_ogre_1_1_axis_aligned_box.html#a7eb90fc1c73bcb4a817ab77ff068f24a", null ],
      [ "getMaximum", "class_ogre_1_1_axis_aligned_box.html#a20bb747949b258bf89836d29d71f84bd", null ],
      [ "setMinimum", "class_ogre_1_1_axis_aligned_box.html#ace4bd8141eb4f5984e52a6cb31e7a571", null ],
      [ "setMinimum", "class_ogre_1_1_axis_aligned_box.html#aebb44ed507a75cdfbc4bc0fff365ffc7", null ],
      [ "setMinimumX", "class_ogre_1_1_axis_aligned_box.html#a3142685d30334a229535ae5265d65dd0", null ],
      [ "setMinimumY", "class_ogre_1_1_axis_aligned_box.html#ae3870fdd15eec672cbb31a72243b9099", null ],
      [ "setMinimumZ", "class_ogre_1_1_axis_aligned_box.html#a18b7996a011d896e1e2065acce0bac67", null ],
      [ "setMaximum", "class_ogre_1_1_axis_aligned_box.html#a76ad2dc729fbee83db77e0fa1eb101ed", null ],
      [ "setMaximum", "class_ogre_1_1_axis_aligned_box.html#ae61ad12fad9545d49554ac6fcb9da224", null ],
      [ "setMaximumX", "class_ogre_1_1_axis_aligned_box.html#a283c031dbabc054cde094b97d1a9e7dc", null ],
      [ "setMaximumY", "class_ogre_1_1_axis_aligned_box.html#ab8f460db81d836e4b898e9f326c324d0", null ],
      [ "setMaximumZ", "class_ogre_1_1_axis_aligned_box.html#a7707872f77222c8eef359b4b7e14c2e5", null ],
      [ "setExtents", "class_ogre_1_1_axis_aligned_box.html#a6de5f05eea95ab39fe83349238e210c5", null ],
      [ "setExtents", "class_ogre_1_1_axis_aligned_box.html#a2e0be3251dbe51eec06999a0a9380359", null ],
      [ "getAllCorners", "class_ogre_1_1_axis_aligned_box.html#a06b43f8e28f97f00acbe80444786839f", null ],
      [ "getCorner", "class_ogre_1_1_axis_aligned_box.html#ae941f98591ec937ed8c8d4b39795db67", null ],
      [ "merge", "class_ogre_1_1_axis_aligned_box.html#a569d00c84979da765abfc66a64b25b68", null ],
      [ "merge", "class_ogre_1_1_axis_aligned_box.html#af3ad8fdc676dc194817f6b7699914d5d", null ],
      [ "transform", "class_ogre_1_1_axis_aligned_box.html#ae2e7a8dc14154120b288aabd468fe9d3", null ],
      [ "transform", "class_ogre_1_1_axis_aligned_box.html#aefda8f8b625a288d833730d4b2feb099", null ],
      [ "setNull", "class_ogre_1_1_axis_aligned_box.html#aa7428e161d37a9715501c678d919eb2a", null ],
      [ "isNull", "class_ogre_1_1_axis_aligned_box.html#a2ba95e1e5c7d3cf869e0144d4233d038", null ],
      [ "isFinite", "class_ogre_1_1_axis_aligned_box.html#add7b06de5a0ba0a53ef56ec66df073d4", null ],
      [ "setInfinite", "class_ogre_1_1_axis_aligned_box.html#a1d02be8fab444a465b52795175fe52dc", null ],
      [ "isInfinite", "class_ogre_1_1_axis_aligned_box.html#ac30510d2cc6d94895a019eff6c9b3712", null ],
      [ "intersects", "class_ogre_1_1_axis_aligned_box.html#aa248737509768d1016c0fa36313b310c", null ],
      [ "intersection", "class_ogre_1_1_axis_aligned_box.html#aaabc20c599407d00f563b8e71db6a4e5", null ],
      [ "volume", "class_ogre_1_1_axis_aligned_box.html#a4e8c385234da6a08d8db3371355b9e5f", null ],
      [ "scale", "class_ogre_1_1_axis_aligned_box.html#ad77340197d2e06137e82cbae79c895ee", null ],
      [ "intersects", "class_ogre_1_1_axis_aligned_box.html#a5a508f817edab7a8d084cffe051d08a7", null ],
      [ "intersects", "class_ogre_1_1_axis_aligned_box.html#aca408c7b88cfc2bcddde8bac8095f0ef", null ],
      [ "intersects", "class_ogre_1_1_axis_aligned_box.html#a0677b231a68bb6f8fb47a7721d2a0a59", null ],
      [ "getCenter", "class_ogre_1_1_axis_aligned_box.html#a7d3b8860ddae5efd2a81b4b0c473ff5d", null ],
      [ "getSize", "class_ogre_1_1_axis_aligned_box.html#af7b08b182001076152493c08aab0f162", null ],
      [ "getHalfSize", "class_ogre_1_1_axis_aligned_box.html#a74fad89d74c05e93e20c23b674328d64", null ],
      [ "contains", "class_ogre_1_1_axis_aligned_box.html#add94e07188153b2814c5854066b1626b", null ],
      [ "squaredDistance", "class_ogre_1_1_axis_aligned_box.html#a74296785f74d1c1f0d3d306be304aa88", null ],
      [ "distance", "class_ogre_1_1_axis_aligned_box.html#aa52a0227880a6d6487007c939de260c5", null ],
      [ "contains", "class_ogre_1_1_axis_aligned_box.html#aeeaf7fff274080e2c941fc994d7510ed", null ],
      [ "operator==", "class_ogre_1_1_axis_aligned_box.html#a7ae41e766810b8d222cd1b13015961fe", null ],
      [ "operator!=", "class_ogre_1_1_axis_aligned_box.html#a9b836910838871e786c621e63257ef8b", null ],
      [ "operator<<", "class_ogre_1_1_axis_aligned_box.html#a7269be019400a8a82c10adb443e42e8e", null ],
      [ "BOX_NULL", "class_ogre_1_1_axis_aligned_box.html#a4d1a5a62c7c38d0831c6073f7343f70f", null ],
      [ "BOX_INFINITE", "class_ogre_1_1_axis_aligned_box.html#ad1b10226c7dd82d5714f8d50c5fd4e04", null ]
    ] ],
    [ "Ogre::Bitwise", "class_ogre_1_1_bitwise.html", [
      [ "bswap16", "class_ogre_1_1_bitwise.html#a0b1d028f1096f238ee55edeab8ae2ddb", null ],
      [ "bswap32", "class_ogre_1_1_bitwise.html#a57dfaedebcc052332b93f66cf6f94eab", null ],
      [ "bswap64", "class_ogre_1_1_bitwise.html#a6002161bc5037d299a0449921ecd22dd", null ],
      [ "bswapBuffer", "class_ogre_1_1_bitwise.html#a26be444ef54cc196d29f801635352e59", null ],
      [ "bswapChunks", "class_ogre_1_1_bitwise.html#ad1df153ede686f618fe227ea7c244127", null ],
      [ "mostSignificantBitSet", "class_ogre_1_1_bitwise.html#a4dc50cb228aa55dabd09a0bb7039e255", null ],
      [ "firstPO2From", "class_ogre_1_1_bitwise.html#af106a2c3cd7b4e3d4e61f72c39eda4a3", null ],
      [ "isPO2", "class_ogre_1_1_bitwise.html#a7e410c698fb0246b5e63ca14fcd0d7d7", null ],
      [ "getBitShift", "class_ogre_1_1_bitwise.html#a87228931b0697ca06bd4131bb93f7d58", null ],
      [ "convertBitPattern", "class_ogre_1_1_bitwise.html#a65c7e2d0a2b2278e58450bb9d289e148", null ],
      [ "fixedToFixed", "class_ogre_1_1_bitwise.html#aa59b3726641c31b63aa3e203559ca3bd", null ],
      [ "floatToFixed", "class_ogre_1_1_bitwise.html#ad3f4d30ecc1aa5ea112a38e63a47b9c8", null ],
      [ "fixedToFloat", "class_ogre_1_1_bitwise.html#a48006ba79d6f8c690e3131c7b4e441bf", null ],
      [ "intWrite", "class_ogre_1_1_bitwise.html#afa88e9d32bbc468ac3ee803ee4228ca1", null ],
      [ "intRead", "class_ogre_1_1_bitwise.html#ad0fcaa2e4f445d1e9c1fb69291061dec", null ],
      [ "floatToHalf", "class_ogre_1_1_bitwise.html#aa02a9c5a117baf2da38ad562c2130681", null ],
      [ "floatToHalfI", "class_ogre_1_1_bitwise.html#ae135638c0cf50cd81dc6355325e0ed21", null ],
      [ "halfToFloat", "class_ogre_1_1_bitwise.html#abb3cbaa74865420859ba7b1061f8d3f3", null ],
      [ "halfToFloatI", "class_ogre_1_1_bitwise.html#ae009f79c8946b451ca7ea2ec599eaf3b", null ]
    ] ],
    [ "Ogre::ConvexBody", "class_ogre_1_1_convex_body.html", [
      [ "PolygonList", "class_ogre_1_1_convex_body.html#a1c5095efca4da37552dcbe1de92e62a4", null ],
      [ "ConvexBody", "class_ogre_1_1_convex_body.html#a55e376da89733093d9061f2b5acebfb2", null ],
      [ "~ConvexBody", "class_ogre_1_1_convex_body.html#a6f643f10031458c33cc9b51dc4a8f893", null ],
      [ "ConvexBody", "class_ogre_1_1_convex_body.html#ae9792f9784f57a75d89a8aecb9ee2f58", null ],
      [ "define", "class_ogre_1_1_convex_body.html#a9abd096ec64a6eedbd942a4f15ae4c34", null ],
      [ "define", "class_ogre_1_1_convex_body.html#af344427771b8ee0bde94a04e68cf4b77", null ],
      [ "clip", "class_ogre_1_1_convex_body.html#af5fb91ac168eec8056adb7b2677523e1", null ],
      [ "clip", "class_ogre_1_1_convex_body.html#ad414f1e05c49050f464c164b9da8e04d", null ],
      [ "clip", "class_ogre_1_1_convex_body.html#a132ccd23a0b43b15077605d813051c4d", null ],
      [ "clip", "class_ogre_1_1_convex_body.html#ac8a3f100f1b91cadf03ec2b9d9d6f684", null ],
      [ "extend", "class_ogre_1_1_convex_body.html#ab281318edcb6f9438693caecf718616c", null ],
      [ "reset", "class_ogre_1_1_convex_body.html#a153a0fac3f0c9687a969a2565ccd320e", null ],
      [ "getPolygonCount", "class_ogre_1_1_convex_body.html#a750bb05cbde7696401cfdd4720bdf707", null ],
      [ "getVertexCount", "class_ogre_1_1_convex_body.html#ad9196b29ab1a8e0a54fb16305b451fe4", null ],
      [ "getPolygon", "class_ogre_1_1_convex_body.html#a7ef85ab9e30dc813363dc19f948c366d", null ],
      [ "getVertex", "class_ogre_1_1_convex_body.html#adfbbf661c51787908f15b76fc3d55244", null ],
      [ "getNormal", "class_ogre_1_1_convex_body.html#adc59c3d0b3e04d6a6d8880ef858294bc", null ],
      [ "getAABB", "class_ogre_1_1_convex_body.html#a90ca1faff14ea4af44433dc9d7c9b5d5", null ],
      [ "hasClosedHull", "class_ogre_1_1_convex_body.html#aab902f05e2959ef81806090841a54339", null ],
      [ "mergePolygons", "class_ogre_1_1_convex_body.html#a4d33db4b9003a76a299649cede0c5557", null ],
      [ "operator==", "class_ogre_1_1_convex_body.html#a4e593920ea98ece61095ff1db3ad3150", null ],
      [ "operator!=", "class_ogre_1_1_convex_body.html#a575cb975ec5246022b2069991295ea42", null ],
      [ "_initialisePool", "class_ogre_1_1_convex_body.html#a59fb24ee9a509ade6490ad1d9aac16d7", null ],
      [ "_destroyPool", "class_ogre_1_1_convex_body.html#a0858a878ce677241ef5632b04a7ffea4", null ],
      [ "operator<<", "class_ogre_1_1_convex_body.html#a721a3cee58ba77cfed605fb589360e31", null ]
    ] ],
    [ "Ogre::Degree", "class_ogre_1_1_degree.html", [
      [ "Degree", "class_ogre_1_1_degree.html#a361f3a162b7b0a234cceecef045c6a30", null ],
      [ "Degree", "class_ogre_1_1_degree.html#a38f343d7b34d2239c9c5ec7270639b86", null ],
      [ "Degree", "class_ogre_1_1_degree.html#aa4de11c233003ffb99fc51951a207889", null ],
      [ "operator=", "class_ogre_1_1_degree.html#a720ae822fce72eb4de3a6c6b59e27f4d", null ],
      [ "operator=", "class_ogre_1_1_degree.html#a6fe71d74f931c1d5525a676ce4defecb", null ],
      [ "operator=", "class_ogre_1_1_degree.html#a8cf6e7cea4ceba86260f0a00e10843a7", null ],
      [ "valueDegrees", "class_ogre_1_1_degree.html#ae7ec7b667395a6e9fb79a92c55a9c5ec", null ],
      [ "valueRadians", "group___math.html#ga01235157bea1375e48ed73634a6f9a18", null ],
      [ "valueAngleUnits", "group___math.html#ga1fd64f1fc097bf4724b4713ff76cdfcd", null ],
      [ "operator+", "class_ogre_1_1_degree.html#ab96e1c8373070e5a990e523f4e0069f0", null ],
      [ "operator+", "class_ogre_1_1_degree.html#a8aed655684943ae384e45378b65da36a", null ],
      [ "operator+", "class_ogre_1_1_degree.html#a77fbb11439e3b9f3ce56af331737484d", null ],
      [ "operator+=", "class_ogre_1_1_degree.html#a2b55c39e79732312bef15ce6a217d206", null ],
      [ "operator+=", "class_ogre_1_1_degree.html#a7f2eded374257421684267738fb476a4", null ],
      [ "operator-", "class_ogre_1_1_degree.html#a3948efcffa54a0ebd12753acd96c1594", null ],
      [ "operator-", "class_ogre_1_1_degree.html#af2441af959738661a1a2251eb16e54bb", null ],
      [ "operator-", "class_ogre_1_1_degree.html#a830559610ea7662565d6ea1107952e51", null ],
      [ "operator-=", "class_ogre_1_1_degree.html#accdd399875d49f167ecfcd3c815d75b5", null ],
      [ "operator-=", "class_ogre_1_1_degree.html#acd2201c018ae74f013542664c2086be0", null ],
      [ "operator*", "class_ogre_1_1_degree.html#ac84420f8ca8ca97730058c16af2bff88", null ],
      [ "operator*", "class_ogre_1_1_degree.html#a8ccdef2435d0a205feb54763d8be5fc9", null ],
      [ "operator*=", "class_ogre_1_1_degree.html#a5db30a075125ac5f9742dac1de7e83e4", null ],
      [ "operator/", "class_ogre_1_1_degree.html#acd0fcb50083c8ee7ef0c4bc936aa0bbd", null ],
      [ "operator/=", "class_ogre_1_1_degree.html#a0934993b96599628b37a28082aa35189", null ],
      [ "operator<", "class_ogre_1_1_degree.html#a1b21b5dd134a959f2ff0b4fc36bf2519", null ],
      [ "operator<=", "class_ogre_1_1_degree.html#ace8f3be58aeb1dcb44fe9d9865fb47c6", null ],
      [ "operator==", "class_ogre_1_1_degree.html#a7bc078c3f3df2ec10ac2d058d29e6e7d", null ],
      [ "operator!=", "class_ogre_1_1_degree.html#a3985fcbd2b8eb22a9d369a6b6ebe5763", null ],
      [ "operator>=", "class_ogre_1_1_degree.html#aae5eef4a46d40d762e159610a9905c9f", null ],
      [ "operator>", "class_ogre_1_1_degree.html#a501f79ce69c3a73d5c07c945c3251097", null ],
      [ "operator<<", "class_ogre_1_1_degree.html#adc93f437d32694bc6e63d0381c641031", null ]
    ] ],
    [ "Ogre::DualQuaternion", "class_ogre_1_1_dual_quaternion.html", [
      [ "DualQuaternion", "class_ogre_1_1_dual_quaternion.html#a80edaf9534e9738f6125ecec0e30ca61", null ],
      [ "DualQuaternion", "class_ogre_1_1_dual_quaternion.html#a845da9e63d380d8b71ea6f740b7fd4a1", null ],
      [ "DualQuaternion", "class_ogre_1_1_dual_quaternion.html#ab9a8e9b8ced4f48e624f12097a5a21f0", null ],
      [ "DualQuaternion", "class_ogre_1_1_dual_quaternion.html#a10574bf89fef9fc12fac5ed4e8085f71", null ],
      [ "DualQuaternion", "class_ogre_1_1_dual_quaternion.html#a303afd76b65bd34a28accdb6eb0c024c", null ],
      [ "operator[]", "class_ogre_1_1_dual_quaternion.html#aac4241fa632d45ee6ae2d155914ddff7", null ],
      [ "operator[]", "class_ogre_1_1_dual_quaternion.html#a8ded07404f68d17e6ca1a201388a12ef", null ],
      [ "operator=", "class_ogre_1_1_dual_quaternion.html#a024daf85de3ed5b28ac41d490012dd2f", null ],
      [ "operator==", "class_ogre_1_1_dual_quaternion.html#a0eb3f8e285a3aaddb6867f24486dbf21", null ],
      [ "operator!=", "class_ogre_1_1_dual_quaternion.html#a67e838a3d4ab670c3a4ef9c62293b038", null ],
      [ "ptr", "class_ogre_1_1_dual_quaternion.html#ab4d4c2f01498ee81a8b8ecc9da60b7ac", null ],
      [ "ptr", "class_ogre_1_1_dual_quaternion.html#ac3a7354ad24b4cfed5572361bc27c8d2", null ],
      [ "swap", "class_ogre_1_1_dual_quaternion.html#a80c92016a8442946a264b8c13ba9f300", null ],
      [ "isNaN", "class_ogre_1_1_dual_quaternion.html#a829e80b909334ea343c106c5fcc29fd5", null ],
      [ "fromRotationTranslation", "class_ogre_1_1_dual_quaternion.html#ad753b864d41eab164118718b27a46425", null ],
      [ "toRotationTranslation", "class_ogre_1_1_dual_quaternion.html#ab208a261f08d2fc8e95025f294a305c1", null ],
      [ "fromTransformationMatrix", "class_ogre_1_1_dual_quaternion.html#ae0fb2ddae4bd51a155b310543dcaa161", null ],
      [ "toTransformationMatrix", "class_ogre_1_1_dual_quaternion.html#a16fefc12aaa35460748c8dfc253d39f1", null ],
      [ "operator<<", "class_ogre_1_1_dual_quaternion.html#aa1b8bcff8bd24a240e237d2adf9f4da5", null ],
      [ "w", "class_ogre_1_1_dual_quaternion.html#a4e1b52752fb889035e68f893f2a246c6", null ],
      [ "x", "class_ogre_1_1_dual_quaternion.html#a1afbb66b83f2085f452bb663ceafc9dc", null ],
      [ "y", "class_ogre_1_1_dual_quaternion.html#a43375b322ae7a0b7f5d03318bfa33f17", null ],
      [ "z", "class_ogre_1_1_dual_quaternion.html#aca62cb2fb2eeab0637b35bc920a7cae4", null ],
      [ "dw", "class_ogre_1_1_dual_quaternion.html#aef3bbc49149643d5bfc3dbde4064dde3", null ],
      [ "dx", "class_ogre_1_1_dual_quaternion.html#a488ce81a7866d481169647cff04dc17c", null ],
      [ "dy", "class_ogre_1_1_dual_quaternion.html#a123fbf0958bccd9f5381d6f124d0586e", null ],
      [ "dz", "class_ogre_1_1_dual_quaternion.html#acfec8064c128940237fe204e7b0e9f99", null ]
    ] ],
    [ "Ogre::EdgeData", "class_ogre_1_1_edge_data.html", [
      [ "Edge", "struct_ogre_1_1_edge_data_1_1_edge.html", [
        [ "triIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#a6ba1f2209d1e9014c76c6acc8f626b96", null ],
        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#aa04881db8275f906b6209b67f77463ab", null ],
        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_edge.html#af8e9e2d2507bd8781c1b34020b4e774a", null ],
        [ "degenerate", "struct_ogre_1_1_edge_data_1_1_edge.html#a83b46b6487ee08a92449c8698fc8fc11", null ]
      ] ],
      [ "EdgeGroup", "struct_ogre_1_1_edge_data_1_1_edge_group.html", [
        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a438a681003c85af04799a2f31988e7e9", null ],
        [ "vertexData", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a1564edb1edb8ee140fd14ee683cae134", null ],
        [ "triStart", "struct_ogre_1_1_edge_data_1_1_edge_group.html#a30fb6c301c0f8cb5ffb940a31a6d6941", null ],
        [ "triCount", "struct_ogre_1_1_edge_data_1_1_edge_group.html#af2d92af1d37412b1d16347129411659b", null ],
        [ "edges", "struct_ogre_1_1_edge_data_1_1_edge_group.html#ac1cefca66bbcb95e3a5b8967bbcd94f2", null ]
      ] ],
      [ "Triangle", "struct_ogre_1_1_edge_data_1_1_triangle.html", [
        [ "Triangle", "struct_ogre_1_1_edge_data_1_1_triangle.html#ac676a82255cafa821af2f4143160f2b1", null ],
        [ "indexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#a9d88cf8afcd62b9ee2c85cd7d1a4b47b", null ],
        [ "vertexSet", "struct_ogre_1_1_edge_data_1_1_triangle.html#ac923c944013258cd8935c0e3650f2cc3", null ],
        [ "vertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#a56a6f686b4e40b69da5a356445cbf258", null ],
        [ "sharedVertIndex", "struct_ogre_1_1_edge_data_1_1_triangle.html#a4aee7f563ba413db670ec0713476400d", null ]
      ] ],
      [ "TriangleFaceNormalList", "class_ogre_1_1_edge_data.html#a0c3b6027adaefeded70c73c18fc5431c", null ],
      [ "TriangleLightFacingList", "class_ogre_1_1_edge_data.html#ac1a64463d85aedbfb38a22cc4bf37390", null ],
      [ "TriangleList", "class_ogre_1_1_edge_data.html#a93de48885b7354fd8eef4501ab9837b8", null ],
      [ "EdgeList", "class_ogre_1_1_edge_data.html#a4051e73185e97a35d022e0cbea91d326", null ],
      [ "EdgeGroupList", "class_ogre_1_1_edge_data.html#a31d0c51b310b6898b168f9c98d94aa24", null ],
      [ "EdgeData", "class_ogre_1_1_edge_data.html#aca13bc3f48d35cacaac6fb72834ab649", null ],
      [ "updateTriangleLightFacing", "class_ogre_1_1_edge_data.html#abc392e96ecd65467b7e17e56f5b6751d", null ],
      [ "updateFaceNormals", "class_ogre_1_1_edge_data.html#a06f4e92565a4b5334aafc92dd923bd12", null ],
      [ "clone", "class_ogre_1_1_edge_data.html#ac25afb403fb4ddc9eb58d6a87bacbf67", null ],
      [ "log", "class_ogre_1_1_edge_data.html#a325ca9f8c825077c2ce6e67d11fd0558", null ],
      [ "triangles", "class_ogre_1_1_edge_data.html#adcd3d9c03ce2bf3a8634b12fe78a9677", null ],
      [ "triangleFaceNormals", "class_ogre_1_1_edge_data.html#ad171b0cbf84c2266e90ccb093485ea9b", null ],
      [ "triangleLightFacings", "class_ogre_1_1_edge_data.html#a846bb6792590b4a3dc9c9f03845feef3", null ],
      [ "edgeGroups", "class_ogre_1_1_edge_data.html#a87c571c8ebe68b3ca039a003ffbe07ad", null ],
      [ "isClosed", "class_ogre_1_1_edge_data.html#a85e8278c626ea184a00081f199d14959", null ]
    ] ],
    [ "Ogre::EdgeListBuilder", "class_ogre_1_1_edge_list_builder.html", [
      [ "EdgeListBuilder", "class_ogre_1_1_edge_list_builder.html#acf52bd519947f6f8305df1bec3247dd2", null ],
      [ "addVertexData", "class_ogre_1_1_edge_list_builder.html#a9845e2f91660819164a627c661f5d107", null ],
      [ "addIndexData", "class_ogre_1_1_edge_list_builder.html#ae4af3550dfe4948680078a087377bfbf", null ],
      [ "build", "class_ogre_1_1_edge_list_builder.html#aa76568f1c0c49f3f9ff16dfb304f1571", null ],
      [ "log", "class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186", null ],
      [ "geometryLess", "class_ogre_1_1_edge_list_builder.html#a99d7b191452d6c4848576f0f3703e0a6", null ]
    ] ],
    [ "Ogre::Math", "class_ogre_1_1_math.html", [
      [ "RandomValueProvider", "class_ogre_1_1_math_1_1_random_value_provider.html", [
        [ "~RandomValueProvider", "class_ogre_1_1_math_1_1_random_value_provider.html#a5f20429fc283dba60a65455f32f96278", null ],
        [ "getRandomUnit", "class_ogre_1_1_math_1_1_random_value_provider.html#a4eae6d750fa52bb50e13291aad808f34", null ]
      ] ],
      [ "AngleUnit", "class_ogre_1_1_math.html#ac8fd1d7167271f824e0210c29ee45ff0", [
        [ "AU_DEGREE", "class_ogre_1_1_math.html#ac8fd1d7167271f824e0210c29ee45ff0aa3cc35278645b4c94a023500eeb06fa5", null ],
        [ "AU_RADIAN", "class_ogre_1_1_math.html#ac8fd1d7167271f824e0210c29ee45ff0a897ddcfb0c6c6491215f0e3555577eee", null ]
      ] ],
      [ "Math", "class_ogre_1_1_math.html#a4b1c2dbd4ad45996551abeab9cda6dd6", null ],
      [ "~Math", "class_ogre_1_1_math.html#a48d9d08ae3a9fc24532482c863a0fa01", null ],
      [ "IAbs", "class_ogre_1_1_math.html#ad9885e718c5559a7acf9f7bb297f41c2", null ],
      [ "ICeil", "class_ogre_1_1_math.html#a9adb00fe453393f48e3c58c993a93e4d", null ],
      [ "IFloor", "class_ogre_1_1_math.html#aece40785651ff1ffa963627fb6da64a6", null ],
      [ "ISign", "class_ogre_1_1_math.html#a8bd528a67c5115c4a806c2bf23111ffe", null ],
      [ "Abs", "class_ogre_1_1_math.html#ae9e2434f05aed3c19b600af6b48c59b7", null ],
      [ "Abs", "class_ogre_1_1_math.html#a38e4535958eded3cec072af7abb1e181", null ],
      [ "Abs", "class_ogre_1_1_math.html#ae753ba9a2539f155a10709bae58625d5", null ],
      [ "ACos", "class_ogre_1_1_math.html#a53869f3197b0f991aea7f5edf6b620e2", null ],
      [ "ASin", "class_ogre_1_1_math.html#acd5aff5514f5a69799661b26803804c5", null ],
      [ "ATan", "class_ogre_1_1_math.html#ad9992a4c4b5b476d8035d4da610467bb", null ],
      [ "ATan2", "class_ogre_1_1_math.html#aca700311c0f4da961015a6625848f611", null ],
      [ "Ceil", "class_ogre_1_1_math.html#aa75e7aa666b0ef3a847416b5646ca955", null ],
      [ "isNaN", "class_ogre_1_1_math.html#a8e299aa79c3a90617cbe764ee977b703", null ],
      [ "Cos", "class_ogre_1_1_math.html#a8070c3fc4eea76025ce9a9072087e540", null ],
      [ "Cos", "class_ogre_1_1_math.html#af8e60f1a04c0bf93d99f0d38d8c6a015", null ],
      [ "Exp", "class_ogre_1_1_math.html#a34452ad868e46e1c9a6b5202f612b390", null ],
      [ "Floor", "class_ogre_1_1_math.html#af362f19574a389ad79fbdd628010daad", null ],
      [ "Log", "class_ogre_1_1_math.html#a09521a106825acbaac711211de57242b", null ],
      [ "Log2", "class_ogre_1_1_math.html#ac453f2205d3deb1c29aa9ef806b8a9ec", null ],
      [ "LogN", "class_ogre_1_1_math.html#a34fe16bca3f1e3083a82412079a5fcdf", null ],
      [ "Pow", "class_ogre_1_1_math.html#ab4038bf12c37a466c025c2de86307a13", null ],
      [ "Sign", "class_ogre_1_1_math.html#a6e0e74db303c82ffa5a1623c14505455", null ],
      [ "Sign", "class_ogre_1_1_math.html#abfd68b4df9b4745a17342650a80e2544", null ],
      [ "Sign", "class_ogre_1_1_math.html#ad9c0f83ef1988f05bc423ac01f8013c4", null ],
      [ "saturate", "class_ogre_1_1_math.html#a11a5dc9a435892a7b4786f9e1c9b997a", null ],
      [ "saturate", "class_ogre_1_1_math.html#a1f5796ed99c642a78c8ab2438752d2b0", null ],
      [ "uint16Cast", "class_ogre_1_1_math.html#a2befae58a1a5e608901955396310c617", null ],
      [ "lerp", "class_ogre_1_1_math.html#aab7bd7f2233826cbfc5f4e2ac51a97d8", null ],
      [ "Sin", "class_ogre_1_1_math.html#a4bf7e39baab4d061f052a9e193d61a1f", null ],
      [ "Sin", "class_ogre_1_1_math.html#a99cbac092e246321386e160a6c27a614", null ],
      [ "Sqr", "class_ogre_1_1_math.html#a626ae51af294ae54cee7e1e530937d7e", null ],
      [ "Sqrt", "class_ogre_1_1_math.html#ab1ee8b71699ce68bd8cf91113ead793e", null ],
      [ "Sqrt", "class_ogre_1_1_math.html#a6bd8cafd36d77c6132c8e0d5061bf6d6", null ],
      [ "Sqrt", "class_ogre_1_1_math.html#a0945a29fc442a83685cff2998b02c348", null ],
      [ "InvSqrt", "class_ogre_1_1_math.html#a4d91be9e4d4f6bb826488f12d70a14f4", null ],
      [ "UnitRandom", "class_ogre_1_1_math.html#ac59f83c8d52180fb9e408bb92d808533", null ],
      [ "RangeRandom", "class_ogre_1_1_math.html#afedce6fa2a819ea7a2420e10fb00a189", null ],
      [ "SymmetricRandom", "class_ogre_1_1_math.html#aa7ee519f461ac44adb2a2c110fb8c194", null ],
      [ "SetRandomValueProvider", "class_ogre_1_1_math.html#a95f03d27b8c0fc1c7f7b947b3146c581", null ],
      [ "Tan", "class_ogre_1_1_math.html#a864447996cc63df237ce7c0a54796212", null ],
      [ "Tan", "class_ogre_1_1_math.html#a13b430149fbd5765175f59a6520cfc03", null ],
      [ "DegreesToRadians", "class_ogre_1_1_math.html#ab346b48871b04bd46ae9d877fe30b416", null ],
      [ "RadiansToDegrees", "class_ogre_1_1_math.html#a157a69d3d7d991975dd3b000842156b2", null ],
      [ "setAngleUnit", "class_ogre_1_1_math.html#afb791263d1e8508fc75f698a20d96b87", null ],
      [ "getAngleUnit", "class_ogre_1_1_math.html#a15efa0bc6eff509b83e61bc6f2465dfa", null ],
      [ "AngleUnitsToRadians", "class_ogre_1_1_math.html#a983534f23650772465406a8c40cef903", null ],
      [ "RadiansToAngleUnits", "class_ogre_1_1_math.html#ac9ce627d71a4d3f824c585339c0a0a0b", null ],
      [ "AngleUnitsToDegrees", "class_ogre_1_1_math.html#acb4fc64359cf3081588bf8a99e0492a6", null ],
      [ "DegreesToAngleUnits", "class_ogre_1_1_math.html#a27e1b2fedaf091309de50261765b8c88", null ],
      [ "pointInTri2D", "class_ogre_1_1_math.html#a2c5d853f3430541b427152b4a1c1229b", null ],
      [ "pointInTri3D", "class_ogre_1_1_math.html#a1d4851d2640e1a9ad98298b8d89351ac", null ],
      [ "intersects", "group___math.html#gafc5955de7b6ba0dfa860cc751c6321db", null ],
      [ "intersects", "group___math.html#ga64ed9272da4fcaccd8b1009a31358c61", null ],
      [ "intersects", "class_ogre_1_1_math.html#ab69d3e2f0de5367ca8da9f7a6a158822", null ],
      [ "intersects", "class_ogre_1_1_math.html#a6297525bcf134fc00bcf347d0bb15ac0", null ],
      [ "intersects", "class_ogre_1_1_math.html#a716bffc8e7a1a2bbb0496b195c91557c", null ],
      [ "intersects", "class_ogre_1_1_math.html#ad11416877e5559b2aa9e1851a588de69", null ],
      [ "intersects", "class_ogre_1_1_math.html#aceb1ac86a8b0b4762ab0f0c97151f753", null ],
      [ "intersects", "group___math.html#gab3e9b9df69bd3255f3b64254e66c3321", null ],
      [ "intersects", "class_ogre_1_1_math.html#a144ae6243207c465be665a58082c878e", null ],
      [ "intersects", "group___math.html#ga04786a5e338650d6eafc987b394d221c", null ],
      [ "RealEqual", "class_ogre_1_1_math.html#a890336e0e4b6914024bfefd79c08f432", null ],
      [ "calculateTangentSpaceVector", "class_ogre_1_1_math.html#a115235aa59b977879a3b889169c7b0f0", null ],
      [ "buildReflectionMatrix", "class_ogre_1_1_math.html#aa339e5bde4dfb3b4cb7e7e47ec998140", null ],
      [ "calculateFaceNormal", "group___math.html#gae5ba1fde5b6a0056fd637d4e6b781a2a", null ],
      [ "calculateBasicFaceNormal", "group___math.html#ga813d02a0ee4c69dab452767fba1cef8a", null ],
      [ "calculateFaceNormalWithoutNormalize", "group___math.html#gabc24b5e11a3a613f60dc44f6056dc61c", null ],
      [ "calculateBasicFaceNormalWithoutNormalize", "group___math.html#gabcc5bd946f4c1fb73b851493e17b11b3", null ],
      [ "gaussianDistribution", "class_ogre_1_1_math.html#a572d6fed0aa293aa6129e3db3605e97c", null ],
      [ "Clamp", "class_ogre_1_1_math.html#a0de224c93b57ff8414892d77f9a2d81d", null ],
      [ "makeViewMatrix", "class_ogre_1_1_math.html#a940f61ee807ac6eecda86b300f125bd8", null ],
      [ "lookRotation", "group___math.html#gae40391520c06bafb34a8647931fab8e1", null ],
      [ "makePerspectiveMatrix", "class_ogre_1_1_math.html#a23c7798ef5a11dea62318b5be2983c2d", null ],
      [ "boundingRadiusFromAABB", "class_ogre_1_1_math.html#a6beb574317f8085bab69587ef7dc72ed", null ],
      [ "boundingRadiusFromAABBCentered", "class_ogre_1_1_math.html#a7e988f7561906c49d7610b57c7bfc728", null ],
      [ "LOG2", "class_ogre_1_1_math.html#ad6c71292d588ec47d0ef82babd95d1d7", null ],
      [ "POS_INFINITY", "class_ogre_1_1_math.html#af26d457d9c540493fd9e3ce2c8b7fa67", null ],
      [ "NEG_INFINITY", "class_ogre_1_1_math.html#a3feaebbfcaab56c8efe2ee33eaaceedd", null ],
      [ "PI", "class_ogre_1_1_math.html#a200402b11219f0c5096d09dc3da22abd", null ],
      [ "TWO_PI", "class_ogre_1_1_math.html#a284c156c5effd4b0d222e4e75ef54af2", null ],
      [ "HALF_PI", "class_ogre_1_1_math.html#a3e55052b57c2cca9b24e146fa902a69e", null ],
      [ "fDeg2Rad", "class_ogre_1_1_math.html#a5d34be36a2ac334dc5ce02dab59322e3", null ],
      [ "fRad2Deg", "class_ogre_1_1_math.html#af0ae410601385d349a6a12e32acc177f", null ]
    ] ],
    [ "Ogre::Matrix3", "class_ogre_1_1_matrix3.html", [
      [ "Matrix3", "class_ogre_1_1_matrix3.html#a0ecaa32a22cc18ca76dc74377005e7e1", null ],
      [ "Matrix3", "class_ogre_1_1_matrix3.html#a705a22877d9f0a33724887e577486b41", null ],
      [ "Matrix3", "class_ogre_1_1_matrix3.html#a3653fb657419f82d71f7ae06df0dd9f5", null ],
      [ "operator[]", "class_ogre_1_1_matrix3.html#aa226e5e2c6e4fb6a3d4c773d9cf33406", null ],
      [ "operator[]", "class_ogre_1_1_matrix3.html#ac312d242a3a978c7e42ffb6bca09bd78", null ],
      [ "GetColumn", "class_ogre_1_1_matrix3.html#a06269d2ba63c85aea763595e44738f79", null ],
      [ "SetColumn", "class_ogre_1_1_matrix3.html#ab5f04bc27bc68152b92123ac2d14afd5", null ],
      [ "FromAxes", "class_ogre_1_1_matrix3.html#ad904362ff107e91ed2881a9802d11979", null ],
      [ "operator==", "class_ogre_1_1_matrix3.html#a0589b1275b7822abd410b13477156d4d", null ],
      [ "operator!=", "class_ogre_1_1_matrix3.html#a2142d22152cd57c522b6936fd523324f", null ],
      [ "operator+", "class_ogre_1_1_matrix3.html#ae3ce939cbbd12eefa0e33933eb2a20cd", null ],
      [ "operator-", "class_ogre_1_1_matrix3.html#ae2e8712b996aab5c818418978b1796d2", null ],
      [ "operator*", "class_ogre_1_1_matrix3.html#aa6e3e20bdf0a5ff536511c968ed5e3d5", null ],
      [ "operator-", "class_ogre_1_1_matrix3.html#abaa901cecc2dce7aacd5dfcc6f5d4f78", null ],
      [ "operator*", "class_ogre_1_1_matrix3.html#a711f681fcd524fe130f651bc819adf0e", null ],
      [ "Transpose", "class_ogre_1_1_matrix3.html#aec1cee52b2574f50b4e98ead1266308b", null ],
      [ "Inverse", "class_ogre_1_1_matrix3.html#ae220004e566c74b9d3121d3073fe84c2", null ],
      [ "Inverse", "class_ogre_1_1_matrix3.html#ab988b3336757c37d3e17e59f410bd88c", null ],
      [ "Determinant", "class_ogre_1_1_matrix3.html#a14cdac95b9c0c688bbeacdf63128fa90", null ],
      [ "transpose", "class_ogre_1_1_matrix3.html#ad340a987162fcf0cb9f4be9ce90996c1", null ],
      [ "inverse", "class_ogre_1_1_matrix3.html#ad0d1a7e8a8b84df6dfd4ea1eba09b9e2", null ],
      [ "determinant", "class_ogre_1_1_matrix3.html#a1c30dfe97a436d47c83f5c9bf603a5bb", null ],
      [ "hasNegativeScale", "class_ogre_1_1_matrix3.html#ae707b42e202609b8aa86fe461ba0f1c2", null ],
      [ "SingularValueDecomposition", "class_ogre_1_1_matrix3.html#a9c4cbf94ffb5400519b60dd4620b595a", null ],
      [ "SingularValueComposition", "class_ogre_1_1_matrix3.html#a1efb2981c1a759e607e1431321d95524", null ],
      [ "orthonormalised", "class_ogre_1_1_matrix3.html#ab2ac89369730e5fea8eca4264304d775", null ],
      [ "Orthonormalize", "class_ogre_1_1_matrix3.html#add64f270c75286c4cafa3b242778573f", null ],
      [ "QDUDecomposition", "class_ogre_1_1_matrix3.html#a67d582443cb581c5deda833897452701", null ],
      [ "SpectralNorm", "class_ogre_1_1_matrix3.html#adca9be180377c51c05a608df576a8e86", null ],
      [ "ToAngleAxis", "class_ogre_1_1_matrix3.html#a383f39c81d80a866ca76594be498a251", null ],
      [ "ToAngleAxis", "class_ogre_1_1_matrix3.html#a392575c590b0d95a1422d1a8fb23260d", null ],
      [ "FromAngleAxis", "class_ogre_1_1_matrix3.html#ab96e7684e128659752ec94031357e6ff", null ],
      [ "ToEulerAnglesXYZ", "class_ogre_1_1_matrix3.html#abd75bf95ae6a7c4294ea710769a77a32", null ],
      [ "ToEulerAnglesXZY", "class_ogre_1_1_matrix3.html#a157ff70e8bd3a611389182497988e3f2", null ],
      [ "ToEulerAnglesYXZ", "class_ogre_1_1_matrix3.html#a799bda89a5b5e774aaeb6ba5197e61ba", null ],
      [ "ToEulerAnglesYZX", "class_ogre_1_1_matrix3.html#a458ebd34fea7df1eb987fee96b5ca2df", null ],
      [ "ToEulerAnglesZXY", "class_ogre_1_1_matrix3.html#ab76be51256dd3773aaaeba380f7969a8", null ],
      [ "ToEulerAnglesZYX", "class_ogre_1_1_matrix3.html#ab1a1b9969db6acbb91178e9c25cfd28d", null ],
      [ "FromEulerAnglesXYZ", "class_ogre_1_1_matrix3.html#a3f5abdecf648a54b164df112c7037ed7", null ],
      [ "FromEulerAnglesXZY", "class_ogre_1_1_matrix3.html#a209f31aa2e25d9b3d55d64d2d8304382", null ],
      [ "FromEulerAnglesYXZ", "class_ogre_1_1_matrix3.html#a2e0ccd0f22689072aa4a64c7a441f694", null ],
      [ "FromEulerAnglesYZX", "class_ogre_1_1_matrix3.html#a94b0b7264cc1572fff22f491ac6cc664", null ],
      [ "FromEulerAnglesZXY", "class_ogre_1_1_matrix3.html#ac0148ffb86f185d7de044fd83e9647ce", null ],
      [ "FromEulerAnglesZYX", "class_ogre_1_1_matrix3.html#a8308f99c3c13e067f016a45f26f15389", null ],
      [ "EigenSolveSymmetric", "class_ogre_1_1_matrix3.html#a7894ad662322338045ae796e418e9df2", null ],
      [ "TensorProduct", "class_ogre_1_1_matrix3.html#af1d217c48e8894227fa2cf2a7952cccc", null ],
      [ "hasScale", "class_ogre_1_1_matrix3.html#adfc89d0edf39f55d9c8e30a8287efcb7", null ],
      [ "Matrix4", "class_ogre_1_1_matrix3.html#aed2829d86d2df8f9333d4c0087455880", null ],
      [ "operator*", "class_ogre_1_1_matrix3.html#a9bc849d4891efcbb40253e790d8f5837", null ],
      [ "operator*", "class_ogre_1_1_matrix3.html#a475a485a770084ade97b8fd310b60011", null ],
      [ "operator<<", "class_ogre_1_1_matrix3.html#a52c928509779ad6a6de8ea4f257d4068", null ],
      [ "EPSILON", "class_ogre_1_1_matrix3.html#a5bf17bf2239af2516e359dc6de22bf3d", null ],
      [ "ZERO", "class_ogre_1_1_matrix3.html#a4561d62d4d2c088ce2a3b6c3ec3d09af", null ],
      [ "IDENTITY", "class_ogre_1_1_matrix3.html#adcb2945d4f9b8995236be5a27dcfe343", null ]
    ] ],
    [ "Ogre::Matrix4", "class_ogre_1_1_matrix4.html", [
      [ "Matrix4", "class_ogre_1_1_matrix4.html#abde37761a7b38997925b6805f6494f72", null ],
      [ "Matrix4", "class_ogre_1_1_matrix4.html#a91cac2ee0f0e8bd582c24db497afcd21", null ],
      [ "Matrix4", "class_ogre_1_1_matrix4.html#a9678081757a65d20052f17c8d6863db4", null ],
      [ "Matrix4", "class_ogre_1_1_matrix4.html#a65ee69637da03019f9efcf3e9d0831b0", null ],
      [ "Matrix4", "class_ogre_1_1_matrix4.html#a8ae0763e439e87045b1ce46dca2c279c", null ],
      [ "Matrix4", "class_ogre_1_1_matrix4.html#aaf7dc461a266459ab6916e7f97991969", null ],
      [ "operator=", "class_ogre_1_1_matrix4.html#a92e755a7c932b7577624a82490c856ae", null ],
      [ "concatenate", "class_ogre_1_1_matrix4.html#a9b550a4d5065bffd37fcc4c0af5b8c30", null ],
      [ "operator==", "class_ogre_1_1_matrix4.html#ac535a3ed291e9518b89f79134b47dd29", null ],
      [ "operator!=", "class_ogre_1_1_matrix4.html#a178b8b39b5b3ac1faa89086f62bf9db9", null ],
      [ "operator*", "class_ogre_1_1_matrix4.html#a9f9cbc672543185e14b45dfab31f63e3", null ],
      [ "adjoint", "class_ogre_1_1_matrix4.html#a0da0cacf5f846f642152e149a965a03d", null ],
      [ "inverse", "class_ogre_1_1_matrix4.html#acd0397dd92f1e5d8c3c5ee7bd269472b", null ],
      [ "ZERO", "class_ogre_1_1_matrix4.html#a838ac3cb744a01a39dfe35c61e942d7a", null ],
      [ "IDENTITY", "class_ogre_1_1_matrix4.html#af2f61127dd1911c9ac2b4cbc0b4f3668", null ],
      [ "CLIPSPACE2DTOIMAGESPACE", "class_ogre_1_1_matrix4.html#a08a798c0d8c8290dbc0287ca6561f549", null ]
    ] ],
    [ "Ogre::OptimisedUtil", "class_ogre_1_1_optimised_util.html", [
      [ "OptimisedUtil", "class_ogre_1_1_optimised_util.html#a4f137d0ced0f82abd042d9b4eb99b105", null ],
      [ "~OptimisedUtil", "class_ogre_1_1_optimised_util.html#a7d548511ecbd6b39d6d1689ce30db8f2", null ],
      [ "getImplementation", "class_ogre_1_1_optimised_util.html#a6ccca012f8a3041746c0694c8ed595b2", null ],
      [ "softwareVertexSkinning", "class_ogre_1_1_optimised_util.html#ae0e1fe21bead4433568514258a2fb965", null ],
      [ "softwareVertexMorph", "class_ogre_1_1_optimised_util.html#a3d72d88494aee0c16ddc21c7c169b0ea", null ],
      [ "concatenateAffineMatrices", "class_ogre_1_1_optimised_util.html#aa625f93ec757b2820935369c9884c45d", null ],
      [ "calculateFaceNormals", "class_ogre_1_1_optimised_util.html#a7fa20b34357e375a489383f0ccb4a15c", null ],
      [ "calculateLightFacing", "class_ogre_1_1_optimised_util.html#a9270e6273fcf190d039030bd5de1df2f", null ],
      [ "extrudeVertices", "class_ogre_1_1_optimised_util.html#a5b411cfc1b916483d75df4f4f9c86252", null ]
    ] ],
    [ "Ogre::Plane", "class_ogre_1_1_plane.html", [
      [ "Side", "class_ogre_1_1_plane.html#aa5d44b14d6f032f3e0a26e83589180bc", [
        [ "NO_SIDE", "class_ogre_1_1_plane.html#aa5d44b14d6f032f3e0a26e83589180bcaad112821a6c39f0097136ba5df53052a", null ],
        [ "POSITIVE_SIDE", "class_ogre_1_1_plane.html#aa5d44b14d6f032f3e0a26e83589180bcac5f2b56ac439b77aad6dfc4031891be5", null ],
        [ "NEGATIVE_SIDE", "class_ogre_1_1_plane.html#aa5d44b14d6f032f3e0a26e83589180bcaaf227c36d02442779fd4600d00580f5e", null ],
        [ "BOTH_SIDE", "class_ogre_1_1_plane.html#aa5d44b14d6f032f3e0a26e83589180bca44420e1c49338ae721f298826e164935", null ]
      ] ],
      [ "Plane", "class_ogre_1_1_plane.html#a1530cc182a2a783e072eabe44f536149", null ],
      [ "Plane", "class_ogre_1_1_plane.html#a296599d7461accceada20df86f7bd334", null ],
      [ "Plane", "class_ogre_1_1_plane.html#a49af67b16939ef95ce83fa89b5aebe07", null ],
      [ "Plane", "class_ogre_1_1_plane.html#a7310d9f018b2f436a789767da8b00836", null ],
      [ "Plane", "class_ogre_1_1_plane.html#abd98e0aae4723943f83262e59cfda535", null ],
      [ "Plane", "class_ogre_1_1_plane.html#adb4cf2fec3619764f0e6766df23b303f", null ],
      [ "getSide", "class_ogre_1_1_plane.html#a519225d752a20f3459d2f0cc20346468", null ],
      [ "getSide", "class_ogre_1_1_plane.html#a7f593c4a54f2d424a8f213421895715e", null ],
      [ "getSide", "class_ogre_1_1_plane.html#a1f4b68ae4354cd7b0cc63374497461cb", null ],
      [ "getDistance", "class_ogre_1_1_plane.html#aa397a61879a2c4ffdc6c237820fae177", null ],
      [ "redefine", "class_ogre_1_1_plane.html#a93b10ba23a8142123cbcac6e4094f15c", null ],
      [ "redefine", "class_ogre_1_1_plane.html#a74dab1f3fb059277cd477aa683b238f7", null ],
      [ "projectVector", "class_ogre_1_1_plane.html#a513a2379245911d5ed1993d5f25c4bef", null ],
      [ "normalise", "class_ogre_1_1_plane.html#a090aae792b4fecc6e8b1b5810f029edf", null ],
      [ "operator-", "class_ogre_1_1_plane.html#ada033b7c48e8628d4e9be5039ffa4278", null ],
      [ "operator==", "class_ogre_1_1_plane.html#a1f5ace6a3a4bedc91a283895fb77a6a8", null ],
      [ "operator!=", "class_ogre_1_1_plane.html#a699e7fd73bffd447e971c97ca38fe3b0", null ],
      [ "operator<<", "class_ogre_1_1_plane.html#a60a89723abe7f05b3e094183bf8903b4", null ],
      [ "normal", "class_ogre_1_1_plane.html#a3f97462d3822f6add8c070048f6c2d92", null ],
      [ "d", "class_ogre_1_1_plane.html#a8e7de1712320968bee111002bc2938b8", null ]
    ] ],
    [ "Ogre::PlaneBoundedVolume", "class_ogre_1_1_plane_bounded_volume.html", [
      [ "PlaneList", "class_ogre_1_1_plane_bounded_volume.html#a52f7c389144c1c587d7fea9e2b8d2a12", null ],
      [ "PlaneBoundedVolume", "class_ogre_1_1_plane_bounded_volume.html#a9f3907950c9fd279e01ac1d4a03d9871", null ],
      [ "PlaneBoundedVolume", "class_ogre_1_1_plane_bounded_volume.html#a1f07490e0ddb2809e1e2b71a89c23856", null ],
      [ "intersects", "class_ogre_1_1_plane_bounded_volume.html#ac92a3d627da4cadbc9ebe7331b368e6e", null ],
      [ "intersects", "class_ogre_1_1_plane_bounded_volume.html#a2381ee685a1657cb601f1859ed8bc9b0", null ],
      [ "intersects", "class_ogre_1_1_plane_bounded_volume.html#a477b753b9fda0c99ccce3e5195b2d7a8", null ],
      [ "planes", "class_ogre_1_1_plane_bounded_volume.html#a20b9a9b8d76a970c5f6cbac4cb438054", null ],
      [ "outside", "class_ogre_1_1_plane_bounded_volume.html#a4d323aac2569fdb268dd6dda2801896e", null ]
    ] ],
    [ "Ogre::Polygon", "class_ogre_1_1_polygon.html", [
      [ "VertexList", "class_ogre_1_1_polygon.html#a9c4c9bf9ae3a6ec59115496a1490e71e", null ],
      [ "EdgeMap", "class_ogre_1_1_polygon.html#a2fa27f282f9404b1b00acf7e37b45b4a", null ],
      [ "Edge", "class_ogre_1_1_polygon.html#a40c084fee97b6c80511ceddcd80a2ca5", null ],
      [ "Polygon", "class_ogre_1_1_polygon.html#a1530c1d4761371c423916f4b497d612e", null ],
      [ "~Polygon", "class_ogre_1_1_polygon.html#a7ce008c85c18f7c28776a7e6b5fb60f3", null ],
      [ "Polygon", "class_ogre_1_1_polygon.html#a86fb38e409c2792034bb6754ff373dc0", null ],
      [ "insertVertex", "class_ogre_1_1_polygon.html#a8853087632d98ac16fa4e1c04e537353", null ],
      [ "insertVertex", "class_ogre_1_1_polygon.html#ac32b2d0a6e7c0cee21471fdaf6da13c4", null ],
      [ "getVertex", "class_ogre_1_1_polygon.html#a54477f45af2ab161d65160461985cacc", null ],
      [ "setVertex", "class_ogre_1_1_polygon.html#a0d19a9876f714cde041e3b7c4598e3b4", null ],
      [ "removeDuplicates", "class_ogre_1_1_polygon.html#a777fe4198b330b2df854b68128299f5c", null ],
      [ "getVertexCount", "class_ogre_1_1_polygon.html#a9d80e759f5c77ba5a308d298c8b498c2", null ],
      [ "getNormal", "class_ogre_1_1_polygon.html#a5dfaeaa196e2005a3a6acad151141d9a", null ],
      [ "deleteVertex", "class_ogre_1_1_polygon.html#a2326d35755fe008fb437c208c6b007d6", null ],
      [ "isPointInside", "class_ogre_1_1_polygon.html#a5fd6676a7f72ed2cb4b96262e7e0b448", null ],
      [ "storeEdges", "class_ogre_1_1_polygon.html#a6c6bde3911911e1bdf7ff2ed93209eda", null ],
      [ "reset", "class_ogre_1_1_polygon.html#a9db9518c3381e7a840610bf181d65b73", null ],
      [ "operator==", "class_ogre_1_1_polygon.html#a268cd4fc6b3eab7805436795dc36d146", null ],
      [ "operator!=", "class_ogre_1_1_polygon.html#a88ae238bdf4e4074d76bffa45b587e37", null ],
      [ "operator=", "class_ogre_1_1_polygon.html#aa5ffcde9852d1d04d51751f7d3b6b794", null ],
      [ "operator<<", "class_ogre_1_1_polygon.html#a642f59093f01be26321a884468a29e54", null ]
    ] ],
    [ "Ogre::Quaternion", "class_ogre_1_1_quaternion.html", [
      [ "Quaternion", "class_ogre_1_1_quaternion.html#ab58dc0c4c04d0579ce9321a719f10d5c", null ],
      [ "Quaternion", "class_ogre_1_1_quaternion.html#a2914eb2c4929ca33650c73d6c0241e59", null ],
      [ "Quaternion", "class_ogre_1_1_quaternion.html#a9b45997a81d85662350808b7043d535d", null ],
      [ "Quaternion", "class_ogre_1_1_quaternion.html#acdcb70a4f122452b6fa70d7cf5ce3cf3", null ],
      [ "Quaternion", "class_ogre_1_1_quaternion.html#a7f25c623d95186b58f6367dcd097a5ba", null ],
      [ "Quaternion", "class_ogre_1_1_quaternion.html#a1140011dc0793a81c55f2d078c8c964c", null ],
      [ "Quaternion", "class_ogre_1_1_quaternion.html#a3ccc60338011887023b397a02a7f3336", null ],
      [ "Quaternion", "class_ogre_1_1_quaternion.html#a1ca81bd9d57e43cf23582c898e5fdd34", null ],
      [ "swap", "class_ogre_1_1_quaternion.html#a54dcd575915c7b7ddb65b8cb249de521", null ],
      [ "operator[]", "class_ogre_1_1_quaternion.html#a390c026412bb0e687f20cfe1bc0ada66", null ],
      [ "operator[]", "class_ogre_1_1_quaternion.html#a8807c9887101c06763af12b57f9caa49", null ],
      [ "ptr", "class_ogre_1_1_quaternion.html#a8233292eaf0b5ae0e9f76af16de2e6ba", null ],
      [ "ptr", "class_ogre_1_1_quaternion.html#ae93aacfa270c23b597e9d03431498927", null ],
      [ "FromRotationMatrix", "class_ogre_1_1_quaternion.html#ae6c3bfed7176355cf2461567f89a15b1", null ],
      [ "ToRotationMatrix", "class_ogre_1_1_quaternion.html#a6005735392c9b07901b8fe160c959f46", null ],
      [ "FromAngleAxis", "class_ogre_1_1_quaternion.html#ac3328c1bb86d17e870c57d52720e2e32", null ],
      [ "ToAngleAxis", "class_ogre_1_1_quaternion.html#a814829e953cbf810c80a8b87626f6324", null ],
      [ "ToAngleAxis", "class_ogre_1_1_quaternion.html#a2fb2913d70c7c4ea6e0799187746401b", null ],
      [ "FromAxes", "class_ogre_1_1_quaternion.html#a7ad7ad40e38bf351485c2a906c3949bb", null ],
      [ "FromAxes", "class_ogre_1_1_quaternion.html#a365bc3b10308318721199a829db03887", null ],
      [ "ToAxes", "class_ogre_1_1_quaternion.html#ae8227891cf00d8fc35bcd455c584f7b0", null ],
      [ "ToAxes", "class_ogre_1_1_quaternion.html#ad4e2661546b7ac4e40b77f38a35ba8d9", null ],
      [ "xAxis", "class_ogre_1_1_quaternion.html#a58a45c5dd46ceee8dbf81dfced570dbe", null ],
      [ "yAxis", "class_ogre_1_1_quaternion.html#aa4915f1a8047e3c8a0a9c380fe3ae695", null ],
      [ "zAxis", "class_ogre_1_1_quaternion.html#a3c41f8bb4147db31ff9674a70de1aad5", null ],
      [ "operator=", "class_ogre_1_1_quaternion.html#a91778b47c7929cbf26bb99b6107608a2", null ],
      [ "operator+", "class_ogre_1_1_quaternion.html#aac3debd2245b0dcefff4ce2fda46eef1", null ],
      [ "operator-", "class_ogre_1_1_quaternion.html#a98993e6f63209a39149d132623bbf41b", null ],
      [ "operator*", "class_ogre_1_1_quaternion.html#af05da43b746cf5b9bc2dcaf3aa4db2b9", null ],
      [ "operator*", "class_ogre_1_1_quaternion.html#af6725db29a7dbc5d6a9071b86ce43714", null ],
      [ "operator-", "class_ogre_1_1_quaternion.html#a24b15dc994247753b7a8064b6a13e2d6", null ],
      [ "operator==", "class_ogre_1_1_quaternion.html#af292a9ed18e3da0bda0fbe114f60cdec", null ],
      [ "operator!=", "class_ogre_1_1_quaternion.html#aec199d4e6af6c82c4026d012eae570cb", null ],
      [ "Dot", "class_ogre_1_1_quaternion.html#a9e14e6aa96e714397b31929299ca681d", null ],
      [ "Norm", "class_ogre_1_1_quaternion.html#a353aafd21ec10c8c07f04472ae6c32b8", null ],
      [ "normalise", "class_ogre_1_1_quaternion.html#aee94ec9c7de50fe7f774ae4c7e760b65", null ],
      [ "Inverse", "class_ogre_1_1_quaternion.html#ae370a6b879cf4d03fb85d8ce510705c1", null ],
      [ "UnitInverse", "class_ogre_1_1_quaternion.html#a821a464cce9a81d5d20c620025043851", null ],
      [ "Exp", "class_ogre_1_1_quaternion.html#ae9c8590b89ed8c8b48a5f188383aeadc", null ],
      [ "Log", "class_ogre_1_1_quaternion.html#a4f89136f9dcb79fef8c47dc418e3e55f", null ],
      [ "operator*", "class_ogre_1_1_quaternion.html#a535ef1c199eee303753507a4a78ddf22", null ],
      [ "getRoll", "class_ogre_1_1_quaternion.html#ae23d3f973fd0f8ac9f188cd513823e3e", null ],
      [ "getPitch", "class_ogre_1_1_quaternion.html#ae4ffd43e74b8b07ddfbc5810a9e6e7ad", null ],
      [ "getYaw", "class_ogre_1_1_quaternion.html#a15c912e62c9abcb3335de205cdf30c2d", null ],
      [ "equals", "class_ogre_1_1_quaternion.html#aaf249bc76b399f92c0c2f93377b032ab", null ],
      [ "orientationEquals", "class_ogre_1_1_quaternion.html#a1df622b500ec13bf405155274e23aa32", null ],
      [ "Slerp", "class_ogre_1_1_quaternion.html#ab0c47f1a7308ac4c17db9f9ddb6e4a72", null ],
      [ "SlerpExtraSpins", "class_ogre_1_1_quaternion.html#a25fb3bc0f11e6a676fb5c47347a79579", null ],
      [ "Intermediate", "class_ogre_1_1_quaternion.html#a838d0736819d496073d99f3f74d0cac1", null ],
      [ "Squad", "class_ogre_1_1_quaternion.html#a5f43da8b8aa579e02035eecff89e16a5", null ],
      [ "nlerp", "class_ogre_1_1_quaternion.html#a16987149991882e148170fe3f1c7da4b", null ],
      [ "isNaN", "class_ogre_1_1_quaternion.html#ac566d9e46f5c1b6368047c132e82a829", null ],
      [ "operator*", "class_ogre_1_1_quaternion.html#a4aea5016e6a48eebee6a31f0a298825e", null ],
      [ "operator<<", "class_ogre_1_1_quaternion.html#a34071780e500a7d64d02a29a41fb6991", null ],
      [ "msEpsilon", "class_ogre_1_1_quaternion.html#a6b53296360cc166c62533cff8f1edcc2", null ],
      [ "ZERO", "class_ogre_1_1_quaternion.html#a44f3c000c8f1ea2759c2e724e04bf86b", null ],
      [ "IDENTITY", "class_ogre_1_1_quaternion.html#a441b8d52549e1dedec27420325a313ef", null ],
      [ "w", "class_ogre_1_1_quaternion.html#af3424f1e07092c0ffe293d18b277a04f", null ],
      [ "x", "class_ogre_1_1_quaternion.html#a32c5680516b41bc4ba3159bf4d4abaf1", null ],
      [ "y", "class_ogre_1_1_quaternion.html#aa7328cd3883a92ee9c9322805d038f11", null ],
      [ "z", "class_ogre_1_1_quaternion.html#a31ec84a931236554c0c17e37bf5ace97", null ]
    ] ],
    [ "Ogre::Radian", "class_ogre_1_1_radian.html", [
      [ "Radian", "class_ogre_1_1_radian.html#a60fa2965b76b7dda53384610683d5c54", null ],
      [ "Radian", "group___math.html#gae928a6c0bafde7b018e386ed94d76a84", null ],
      [ "Radian", "class_ogre_1_1_radian.html#ac804485865972611d50c2fdb32f70c51", null ],
      [ "operator=", "class_ogre_1_1_radian.html#a241e31e75fdffcca006cec4a98088729", null ],
      [ "operator=", "class_ogre_1_1_radian.html#adb530b22870ba5d8c085084e42fd2fb4", null ],
      [ "operator=", "group___math.html#gafab8ce89cde3034f3cc5c2537d5ea6fd", null ],
      [ "valueDegrees", "group___math.html#gaac273cad14f6c100d692d7235919fe7f", null ],
      [ "valueRadians", "class_ogre_1_1_radian.html#accbf4796a0cf6d9703fc8dff822933c9", null ],
      [ "valueAngleUnits", "group___math.html#gae0e1b281e33d85e3364aeaa49c8ef2f5", null ],
      [ "operator+", "class_ogre_1_1_radian.html#aaeab5dabdef48857adc526512ae58b2e", null ],
      [ "operator+", "class_ogre_1_1_radian.html#aac01bc3b1f60064a8d3881ec2b622056", null ],
      [ "operator+", "group___math.html#ga6aee68f4913cf646f4fa3c046a18ee60", null ],
      [ "operator+=", "class_ogre_1_1_radian.html#a023b970eb476f0134e3c26732815068d", null ],
      [ "operator+=", "group___math.html#gaed5147935125e28f53cb19d70055bc88", null ],
      [ "operator-", "class_ogre_1_1_radian.html#aa2366301db74814149be591856884221", null ],
      [ "operator-", "class_ogre_1_1_radian.html#a6e9f6957e298803562bb63ccddeb6717", null ],
      [ "operator-", "group___math.html#ga05fd614aac352a71e17d8eb559578d7b", null ],
      [ "operator-=", "class_ogre_1_1_radian.html#aa3dc0b77ba9cfe2333be86a6601ce882", null ],
      [ "operator-=", "group___math.html#ga223a82b9ff74351959eee91a335e7cdb", null ],
      [ "operator*", "class_ogre_1_1_radian.html#a257fa7fc4831216d7ac42427f75a3ce8", null ],
      [ "operator*", "class_ogre_1_1_radian.html#aaa01cb1c5b32553395c42cf66de94b78", null ],
      [ "operator*=", "class_ogre_1_1_radian.html#aa7b4b0c6ca9d07becac4735c9171d652", null ],
      [ "operator/", "class_ogre_1_1_radian.html#afb27a2ddb69908891610c46779fc0e61", null ],
      [ "operator/=", "class_ogre_1_1_radian.html#a66bc90bdd1427909c4bb057e3585f4a6", null ],
      [ "operator<", "class_ogre_1_1_radian.html#a24c502ed700ae70138c521c14f8102b3", null ],
      [ "operator<=", "class_ogre_1_1_radian.html#a2cc76b722fcf4b67d242359f5ad95718", null ],
      [ "operator==", "class_ogre_1_1_radian.html#abcab875d3abb099a962157bc6d3ff5f7", null ],
      [ "operator!=", "class_ogre_1_1_radian.html#a1ec08644d17b7119bdb5c27c235a4101", null ],
      [ "operator>=", "class_ogre_1_1_radian.html#a2f16c17c310873f209c3464eea4511d0", null ],
      [ "operator>", "class_ogre_1_1_radian.html#a6b34aca5c2b5cbc483dde8f22d3de0a1", null ],
      [ "operator<<", "class_ogre_1_1_radian.html#a4cb0c60481062712ee8407f8a7da308e", null ]
    ] ],
    [ "Ogre::Ray", "class_ogre_1_1_ray.html", [
      [ "Ray", "class_ogre_1_1_ray.html#ae06168a69567ec6ede584cfa8ced9979", null ],
      [ "Ray", "class_ogre_1_1_ray.html#a7da08421bf78a27884c5a381cda60dc2", null ],
      [ "setOrigin", "class_ogre_1_1_ray.html#a730a34d1255a51df2bb072c823acec67", null ],
      [ "getOrigin", "class_ogre_1_1_ray.html#a02bd4209229a1f33c4df090aaf333c99", null ],
      [ "setDirection", "class_ogre_1_1_ray.html#ac3082e7ed2efd58bb202043101d4abb2", null ],
      [ "getDirection", "class_ogre_1_1_ray.html#ae7b963806b1d5ff741b6de745e8e6e17", null ],
      [ "getPoint", "class_ogre_1_1_ray.html#a81a7ec16f410cedf5c279152230bf67b", null ],
      [ "operator*", "class_ogre_1_1_ray.html#afcc111edd38353d3c8aedb0e318127d8", null ],
      [ "intersects", "class_ogre_1_1_ray.html#afa5b7d11cf16bf35f212f6762a3d40e0", null ],
      [ "intersects", "class_ogre_1_1_ray.html#a45ddd7bccb4269f11a9bfebe5bc767c3", null ],
      [ "intersects", "class_ogre_1_1_ray.html#a27c18eed9d9d65197b12c2a2a8053c9c", null ],
      [ "intersects", "class_ogre_1_1_ray.html#af4a15c54cf07c7f0980918390c7f0c7d", null ]
    ] ],
    [ "Ogre::RotationalSpline", "class_ogre_1_1_rotational_spline.html", [
      [ "RotationalSpline", "class_ogre_1_1_rotational_spline.html#ac8596d691089c7be12d2879dc5595cea", null ],
      [ "~RotationalSpline", "class_ogre_1_1_rotational_spline.html#ae7c15794bdabda0d02fb2ce52b3e1ea9", null ],
      [ "addPoint", "class_ogre_1_1_rotational_spline.html#a5ba4e31b2ec1aec5c6c2878440184709", null ],
      [ "getPoint", "class_ogre_1_1_rotational_spline.html#a178dfbe40aaddf826130ab19f5d778a1", null ],
      [ "getNumPoints", "class_ogre_1_1_rotational_spline.html#a92446820612daa332226ab9bf18d7f6a", null ],
      [ "clear", "class_ogre_1_1_rotational_spline.html#ad52da70d8d76c5c6d2203197e14b3520", null ],
      [ "updatePoint", "class_ogre_1_1_rotational_spline.html#a8ee6d15c86ed31e61e04360d36f1fbf9", null ],
      [ "interpolate", "class_ogre_1_1_rotational_spline.html#a4fd498ecda341877bed16614f99513f3", null ],
      [ "interpolate", "class_ogre_1_1_rotational_spline.html#a50e4fac029abebe1f318a80da015f544", null ],
      [ "setAutoCalculate", "class_ogre_1_1_rotational_spline.html#a94645c3887ad1b0872bcea3897fae613", null ],
      [ "recalcTangents", "class_ogre_1_1_rotational_spline.html#a9eec1f4d7ee25b15d435e8c49c69c92a", null ]
    ] ],
    [ "Ogre::SimpleSpline", "class_ogre_1_1_simple_spline.html", [
      [ "SimpleSpline", "class_ogre_1_1_simple_spline.html#a647c5b1ef7ab486fc8646fa6a151bab6", null ],
      [ "~SimpleSpline", "class_ogre_1_1_simple_spline.html#aef641d97c1f208faf7bcf46584706fd8", null ],
      [ "addPoint", "class_ogre_1_1_simple_spline.html#a19945294aede4d865da85ccbe095ad33", null ],
      [ "getPoint", "class_ogre_1_1_simple_spline.html#ae48b2283544f693a48c79ad3e6bc61d3", null ],
      [ "getNumPoints", "class_ogre_1_1_simple_spline.html#a26d51ec5fca7e30d3b92a9f980e63667", null ],
      [ "clear", "class_ogre_1_1_simple_spline.html#ad9b46f66661afbebf4cf1c45182e0484", null ],
      [ "updatePoint", "class_ogre_1_1_simple_spline.html#a5c757c1a320a61e224753b72c5e65048", null ],
      [ "interpolate", "class_ogre_1_1_simple_spline.html#a11afeab4c4889cbfb34a439b9415b09f", null ],
      [ "interpolate", "class_ogre_1_1_simple_spline.html#abb942e88e6e7ef6466688d1fafc1f746", null ],
      [ "setAutoCalculate", "class_ogre_1_1_simple_spline.html#ac8a0d23480006745e3a58ecec33f6bc2", null ],
      [ "recalcTangents", "class_ogre_1_1_simple_spline.html#a2c8896ea995986b58328763e58acbcb0", null ]
    ] ],
    [ "Ogre::Sphere", "class_ogre_1_1_sphere.html", [
      [ "Sphere", "class_ogre_1_1_sphere.html#a93cb05f8025668db930ef81a34dca47b", null ],
      [ "Sphere", "class_ogre_1_1_sphere.html#abd0dc8dd45b400a07d71115652d2dc20", null ],
      [ "getRadius", "class_ogre_1_1_sphere.html#a6306310d834dc7844c73dd24ec7a318d", null ],
      [ "setRadius", "class_ogre_1_1_sphere.html#aafe80cad31edd668b09981a6f836c8b1", null ],
      [ "getCenter", "class_ogre_1_1_sphere.html#afc27f8572366e37a150a45963c4dc247", null ],
      [ "setCenter", "class_ogre_1_1_sphere.html#af2cd29ca81e68cdeb65b91a2667d6fbc", null ],
      [ "intersects", "class_ogre_1_1_sphere.html#a01e832a0542bde80df107ab6b26b56f9", null ],
      [ "intersects", "class_ogre_1_1_sphere.html#a77798ca00493f6b1f9da7f3eff782642", null ],
      [ "intersects", "class_ogre_1_1_sphere.html#a774730a3d40a4375144128b13afc39ef", null ],
      [ "intersects", "class_ogre_1_1_sphere.html#a4a30ba4b71475bf2da82c91dcc13e97a", null ],
      [ "merge", "class_ogre_1_1_sphere.html#a9e9104e8e57c2fa2d30920989c725d1a", null ]
    ] ],
    [ "Ogre::TangentSpaceCalc", "class_ogre_1_1_tangent_space_calc.html", [
      [ "IndexRemap", "struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html", [
        [ "IndexRemap", "struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a77c5b41921797ecfc47252bd99f789aa", null ],
        [ "IndexRemap", "struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a6d5e329458cea922c5d62eaf814b4883", null ],
        [ "indexSet", "struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a0b95b1be05110b59c87d44378f8f2d4b", null ],
        [ "faceIndex", "struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a477c9b282bb1275c79472224d890cab5", null ],
        [ "splitVertex", "struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a28ce54b6e709aa61689b4565cd0acf68", null ]
      ] ],
      [ "Result", "struct_ogre_1_1_tangent_space_calc_1_1_result.html", [
        [ "vertexSplits", "struct_ogre_1_1_tangent_space_calc_1_1_result.html#adc7a5f1543644476242dfad6552342b6", null ],
        [ "indexesRemapped", "struct_ogre_1_1_tangent_space_calc_1_1_result.html#a0e5e34d6936c7a3e76ad6e4d03688df8", null ]
      ] ],
      [ "VertexSplit", "class_ogre_1_1_tangent_space_calc.html#a3b4ae87819072eef7073c3e71a0735be", null ],
      [ "IndexRemapList", "class_ogre_1_1_tangent_space_calc.html#af6497ad40b68863ff56ad526dd8cea2a", null ],
      [ "VertexSplits", "class_ogre_1_1_tangent_space_calc.html#abe9e4513618517d0b4c98da866b85648", null ],
      [ "TangentSpaceCalc", "class_ogre_1_1_tangent_space_calc.html#a33eeb35f74cfa2d2c90ab7b138763752", null ],
      [ "clear", "class_ogre_1_1_tangent_space_calc.html#afd150caf2af93ec05fcbc836641e894a", null ],
      [ "setVertexData", "class_ogre_1_1_tangent_space_calc.html#aac1530e73ac67068755e65063965fe98", null ],
      [ "addIndexData", "class_ogre_1_1_tangent_space_calc.html#aa15868f47d97e86805e75ee53ffe66a2", null ],
      [ "setStoreParityInW", "class_ogre_1_1_tangent_space_calc.html#a637794857196e7b6bec4974b97ee5a50", null ],
      [ "getStoreParityInW", "class_ogre_1_1_tangent_space_calc.html#a9edb082fa98b5cbe85034c1abe7d02f6", null ],
      [ "setSplitMirrored", "class_ogre_1_1_tangent_space_calc.html#a43107313dd9e1fefb5a0f0760792ac45", null ],
      [ "getSplitMirrored", "class_ogre_1_1_tangent_space_calc.html#aff282be1144cc20f9eb669fcb33393c2", null ],
      [ "setSplitRotated", "class_ogre_1_1_tangent_space_calc.html#a3b9ef4ec951f3a95e40697d7c6637a7d", null ],
      [ "getSplitRotated", "class_ogre_1_1_tangent_space_calc.html#a2108f7fcd81d75bf2417f2ca45244f3e", null ],
      [ "build", "class_ogre_1_1_tangent_space_calc.html#a6a40ae15c9fd4912a8bd63b91997bbe8", null ],
      [ "build", "class_ogre_1_1_tangent_space_calc.html#aef80f3ebc3e34e9fc0cca9a7ebb25d8b", null ]
    ] ],
    [ "Ogre::TransformBase< rows, T >", "class_ogre_1_1_transform_base.html", [
      [ "TransformBase", "class_ogre_1_1_transform_base.html#acf3bcb9d0a7bffe8a2de6bb629db7c22", null ],
      [ "TransformBase", "class_ogre_1_1_transform_base.html#a8ad24267976ae7b6f588bf3164aaf46a", null ],
      [ "TransformBase", "class_ogre_1_1_transform_base.html#a7a196d18c3ea563e3c7d6f98867e3148", null ],
      [ "operator[]", "class_ogre_1_1_transform_base.html#a46e3c6d4c19251daf67330b3bb09d277", null ],
      [ "operator[]", "class_ogre_1_1_transform_base.html#a47755d4a75916b8682f61a2bd36f9d70", null ],
      [ "setTrans", "class_ogre_1_1_transform_base.html#acd424a976abe0bd586dd6b46876dc235", null ],
      [ "getTrans", "class_ogre_1_1_transform_base.html#a673d5c7fc1c6c170e2bebb1a9f881745", null ],
      [ "setScale", "class_ogre_1_1_transform_base.html#ac029df849f85850a59921e5f361927c4", null ],
      [ "operator<<", "class_ogre_1_1_transform_base.html#a3b5fd96b6329e1bb667321b41ae85e98", null ]
    ] ],
    [ "Ogre::TransformBaseReal", "struct_ogre_1_1_transform_base_real.html", [
      [ "TransformBaseReal", "struct_ogre_1_1_transform_base_real.html#aa50988f8c92bdb7fd881b33711f0f0f2", null ],
      [ "TransformBaseReal", "struct_ogre_1_1_transform_base_real.html#ae5a711e0c1c9681ecabaf30a1ffccc2c", null ],
      [ "makeTrans", "struct_ogre_1_1_transform_base_real.html#ab5d6ffc4f1604d59552be2c4d9f4a01a", null ],
      [ "makeTrans", "struct_ogre_1_1_transform_base_real.html#aa0f27bb6d140ca1d09a03c9e27c5f96c", null ],
      [ "set3x3Matrix", "struct_ogre_1_1_transform_base_real.html#aebf4846bf9c86970bc9569d132892708", null ],
      [ "linear", "struct_ogre_1_1_transform_base_real.html#a99c2bd12bee6aedcb27fcd4cd70e1a6b", null ],
      [ "extract3x3Matrix", "struct_ogre_1_1_transform_base_real.html#a3f43524c27cb439313bd081ae280642c", null ],
      [ "extractQuaternion", "struct_ogre_1_1_transform_base_real.html#aef6aefde7236f81a2343af8a1d81da50", null ],
      [ "determinant", "struct_ogre_1_1_transform_base_real.html#a9abae638b21413a41bc5b004ecacecd4", null ],
      [ "transpose", "group___math.html#gaebc7c568cc1d6f13405a756be1af73fa", null ],
      [ "makeTransform", "struct_ogre_1_1_transform_base_real.html#ad58c2d3fb3345558228fe3bafdf1b732", null ],
      [ "makeInverseTransform", "struct_ogre_1_1_transform_base_real.html#abf2a16142c5dfd6360fb5e697fbf578d", null ]
    ] ],
    [ "Ogre::Vector< dims, T >", "class_ogre_1_1_vector.html", [
      [ "Vector", "class_ogre_1_1_vector.html#a7d01f88f113d198ac5ee8b961c6d8823", null ],
      [ "Vector", "class_ogre_1_1_vector.html#ae6f3059c85986465741bf40fbe5ae348", null ],
      [ "Vector", "class_ogre_1_1_vector.html#af56d266815fd97c34840189945b67cfa", null ],
      [ "Vector", "class_ogre_1_1_vector.html#a8d9fe8c6b9bcb237278eae92a5e95a58", null ],
      [ "Vector", "class_ogre_1_1_vector.html#a965a21067d3f872afec2621d81b798bb", null ],
      [ "Vector", "class_ogre_1_1_vector.html#a389e8be5818ba2c48c525441ce862f06", null ],
      [ "Vector", "class_ogre_1_1_vector.html#a08b4b207bff9bb43d77fe6133a0e4980", null ],
      [ "Vector", "class_ogre_1_1_vector.html#a921c3ae9fd07f00bf5abcf39de7e5640", null ],
      [ "xyz", "class_ogre_1_1_vector.html#aef137b5ab3bbe5b8fd7f38e8715acf6e", null ],
      [ "xy", "class_ogre_1_1_vector.html#aa2f169d64e7a5e0a6947292e2b6c41a0", null ],
      [ "operator[]", "class_ogre_1_1_vector.html#a94180c95cb7c54c16578c481172c851d", null ],
      [ "operator[]", "class_ogre_1_1_vector.html#ab1a181e679e7eb4dfd26f1385afa3a25", null ],
      [ "operator==", "class_ogre_1_1_vector.html#a58d55aa3c2d3f5d64b8424c03273c22a", null ],
      [ "positionEquals", "class_ogre_1_1_vector.html#ab147f247dcbe9cf0d2294f6633fb6e2b", null ],
      [ "operator!=", "class_ogre_1_1_vector.html#aeae20c648b8901369a7f2fbb517ce14c", null ],
      [ "operator<", "class_ogre_1_1_vector.html#aac498789a02f7c024cede36f983c3c6a", null ],
      [ "operator>", "class_ogre_1_1_vector.html#a082701eff89181d07e677ce7cd238a39", null ],
      [ "makeFloor", "class_ogre_1_1_vector.html#abd61147c1de293b472d575e9e2d9c1c6", null ],
      [ "makeCeil", "class_ogre_1_1_vector.html#abfd91a0fd283f8360079680e21ae40d4", null ],
      [ "dotProduct", "class_ogre_1_1_vector.html#ae610ff4982860298852e56af6b2fe36c", null ],
      [ "squaredLength", "class_ogre_1_1_vector.html#ae3644507471a16eb79a5b5480a8f4d9f", null ],
      [ "isZeroLength", "class_ogre_1_1_vector.html#a898d6f71ca95d09f784a97ee7129cf46", null ],
      [ "length", "class_ogre_1_1_vector.html#a4e720e2f113f8c98192bc61dbcf1bddc", null ],
      [ "distance", "class_ogre_1_1_vector.html#a94d43755b7ab8ef60b8809d942579e8c", null ],
      [ "squaredDistance", "class_ogre_1_1_vector.html#a5480f610064a6f1c6895e528ff06c192", null ],
      [ "normalise", "class_ogre_1_1_vector.html#a2d9b321bec779fc06de480897cda2027", null ],
      [ "normalisedCopy", "class_ogre_1_1_vector.html#a43169cee2146a35d14ef47016f565d23", null ],
      [ "isNaN", "class_ogre_1_1_vector.html#a94e94ab01f806ed6c2a1931e3d5cc423", null ],
      [ "angleBetween", "class_ogre_1_1_vector.html#a5ba1b2a4ccc2cac6a5155718a2a8aeee", null ],
      [ "reflect", "class_ogre_1_1_vector.html#a0191e4be3471b658a601483f0f466c84", null ],
      [ "operator*=", "class_ogre_1_1_vector.html#a7aaced16349c475ca35f15c49de5a2af", null ],
      [ "operator/=", "class_ogre_1_1_vector.html#a271600f4222dbbeb7fd0dc225585a1f6", null ],
      [ "operator+=", "class_ogre_1_1_vector.html#a717f6b73d222c95975ff741a60fae160", null ],
      [ "operator-=", "class_ogre_1_1_vector.html#a97d5a3c84ade11168e2b6127c024baf3", null ],
      [ "operator+=", "class_ogre_1_1_vector.html#a0de3560dc5d54192ead99634640fa678", null ],
      [ "operator-=", "class_ogre_1_1_vector.html#a49fc83e35b71c35f34b5deb2c7a6f10e", null ],
      [ "operator*=", "class_ogre_1_1_vector.html#ad23fe94b5e8f4d484a7bebc74c0e6fd8", null ],
      [ "operator/=", "class_ogre_1_1_vector.html#a7fe4a2f88eb25249d6f73c72e36abd98", null ],
      [ "operator-", "class_ogre_1_1_vector.html#a14bf242fa100f9b229146fbd29c51555", null ],
      [ "operator+", "class_ogre_1_1_vector.html#ad6f508fef8974f92445c1b8770ec9fda", null ],
      [ "operator*", "class_ogre_1_1_vector.html#aae091019d5dcf1a45753803ea171bdc3", null ],
      [ "operator/", "class_ogre_1_1_vector.html#a2364e2028d08f8d16a9019774c727dd9", null ],
      [ "operator-", "class_ogre_1_1_vector.html#a117f8d3469d2fdd1b2c7c7b8e1fe72ce", null ],
      [ "operator+", "class_ogre_1_1_vector.html#a0f196244fe8af4e5e146f8692b5fef98", null ],
      [ "operator+", "class_ogre_1_1_vector.html#ac4d0621635c4396acd7559a906fbee5a", null ],
      [ "operator-", "class_ogre_1_1_vector.html#a0b86e1eb1890fc330b6e5fade5937641", null ],
      [ "operator*", "class_ogre_1_1_vector.html#a8a4644dd6de4b9b2cf44ad72498f341e", null ],
      [ "operator/", "class_ogre_1_1_vector.html#ae7537fa260742c6237d30238c8018b1e", null ],
      [ "operator*", "class_ogre_1_1_vector.html#a9811dbb733402b01f1fd067ed84fb1a6", null ],
      [ "operator+", "class_ogre_1_1_vector.html#a44e4f029f3bbd57081fcfb5e197830cf", null ],
      [ "operator-", "class_ogre_1_1_vector.html#ab8749d3209c046e3eba91a17436a7812", null ],
      [ "operator/", "class_ogre_1_1_vector.html#a53dc8e9fa6980e60713fe81b09be5d54", null ],
      [ "operator<<", "class_ogre_1_1_vector.html#ac21eafda481aaffc9c767ad4f5a6dfd7", null ]
    ] ],
    [ "Ogre::VectorBase< dims, T >", "struct_ogre_1_1_vector_base.html", [
      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0", null ],
      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a4780e28e244b3fb69d259d161b01e9a1", null ],
      [ "VectorBase", "struct_ogre_1_1_vector_base.html#a9b095dcc7d2812780a6cbc1163568785", null ],
      [ "VectorBase", "struct_ogre_1_1_vector_base.html#af9ea7a5d9919e101efcca5e41b5d2705", null ],
      [ "ptr", "struct_ogre_1_1_vector_base.html#a68f9ad334839138f1bf767a517f6ba0b", null ],
      [ "ptr", "struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055", null ],
      [ "data", "struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5", null ]
    ] ],
    [ "Ogre::VectorBase< 2, Real >", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", [
      [ "VectorBase", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#abdef156b8ae9ca99b2f6e63e545f93a3", null ],
      [ "VectorBase", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ae2f35d4cb19c32de559b6815badd425b", null ],
      [ "ptr", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a4386098987c58adbe2dd4fedb0d19eed", null ],
      [ "ptr", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a0c9cad7eaa9ffc11623f4bc6ae915ff2", null ],
      [ "midPoint", "group___math.html#ga4345346666fd54473efb51a8d194f5e0", null ],
      [ "crossProduct", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab55e075045abe594d0b7d7b2d232ffe8", null ],
      [ "perpendicular", "group___math.html#ga00e57f3eda32e31277c439e6a9c929a1", null ],
      [ "randomDeviant", "group___math.html#gaba43517feb82c40ccf1cc571f519866c", null ],
      [ "angleTo", "group___math.html#ga7a92915df275eae8161441024d88c815", null ],
      [ "x", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a95a20cb8d244732ea5dadff4b8da7111", null ],
      [ "y", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a5661dd38b03840383dc1a0cbea9199d9", null ],
      [ "ZERO", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#af6df06c614a141cc90fb9fe28b0c34f9", null ],
      [ "UNIT_X", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#adeeb454e50949d89f71b52a38e52951e", null ],
      [ "UNIT_Y", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab771b243b99665aaff02505c273be9ee", null ],
      [ "NEGATIVE_UNIT_X", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a1786bcda5c79f91d70d8d0789ed6ee66", null ],
      [ "NEGATIVE_UNIT_Y", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a5cf013c152017f5af5e3b4b0a93d726c", null ],
      [ "UNIT_SCALE", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a979837f10b7068528efc6802742f5509", null ]
    ] ],
    [ "Ogre::VectorBase< 3, Real >", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", [
      [ "VectorBase", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#afcd99d9db1e0e25bab9f7bea0d4a190a", null ],
      [ "VectorBase", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a9099515f00fb4c790492037a4816c1a9", null ],
      [ "ptr", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a7f6ccde75703a0965eb4bce5f99eeac2", null ],
      [ "ptr", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ad4f4f774fd3c8c2072e659ab36b12f93", null ],
      [ "crossProduct", "group___math.html#gafe9157bbe30e69645edd5c3eddea141f", null ],
      [ "perpendicular", "group___math.html#ga5b50a2b2697ec1ac684d66af82a03296", null ],
      [ "absDotProduct", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2e8982298226fccf166445c68506f087", null ],
      [ "midPoint", "group___math.html#ga929562516cfb30c38030d9df84945bf3", null ],
      [ "randomDeviant", "group___math.html#ga4f54a2dd6b60dd327fcc8347fc4d853d", null ],
      [ "getRotationTo", "group___math.html#gac6ef79da21101ef5a671b0473b849bc3", null ],
      [ "positionCloses", "group___math.html#ga24dd46458beb0ea8175bfbf916f09e47", null ],
      [ "directionEquals", "group___math.html#gad67db81d99c63e2483ff8bc314bfd36c", null ],
      [ "primaryAxis", "group___math.html#gad52e72c687842e8475a5f24cde8cd858", null ],
      [ "x", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2e6b3a89e26268bde6f6347f363a6bd1", null ],
      [ "y", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a5c89e45e32e3cf01cc54dc05ad6704e5", null ],
      [ "z", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a0a242b15c4c3a7181cc5a371b3f86fe3", null ],
      [ "ZERO", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a683a3ae0ddceb4a01a94c0727ca63362", null ],
      [ "UNIT_X", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2fe25096ba980b3569e44833ddf155e6", null ],
      [ "UNIT_Y", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a25a0d767f153bc408453ee85de866c87", null ],
      [ "UNIT_Z", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ab8448c3f1c0a210e465a1aa0e551a33a", null ],
      [ "NEGATIVE_UNIT_X", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#aff2d9ac3a0f7653fc9e5dcef71e80397", null ],
      [ "NEGATIVE_UNIT_Y", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a42a88148edf0e38db8a1fb4ab5d5b499", null ],
      [ "NEGATIVE_UNIT_Z", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ab7cc41b4120afa20f7d74d918ea35dc3", null ],
      [ "UNIT_SCALE", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a89fbc371d11d0363db247d6ef1fa7afa", null ]
    ] ],
    [ "Ogre::VectorBase< 4, Real >", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html", [
      [ "VectorBase", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a50e16e1f758092ba72398d1f71d0bc60", null ],
      [ "VectorBase", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ad1269630b80565f80da462630bd7d5ad", null ],
      [ "ptr", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a687504a38534d7a9cf95fcc56a0ec048", null ],
      [ "ptr", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a363e2d1a068e15325d2f36251c194415", null ],
      [ "x", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ab251c7a2d54e44ad406b99f94fb7bcfd", null ],
      [ "y", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a91aaf7e577df85ef9bb8ec991e85475d", null ],
      [ "z", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a522a1880968a4814d3fca4eeb2a24e29", null ],
      [ "w", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a6816f6bd970974e2fa9e1b0289a7994d", null ],
      [ "ZERO", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ac3d942ae568cc586e83f0ea4415bad64", null ]
    ] ],
    [ "Ogre::RayTestResult", "group___math.html#ga3f791f5ff19bd8395f0008085e68bf10", null ],
    [ "Ogre::PlaneList", "group___math.html#ga4cfa65f236aec1767fc85022e87059a0", null ],
    [ "Ogre::PlaneBoundedVolumeList", "group___math.html#gaf6bda7879d1ac92561a02cbd1833e1b1", null ],
    [ "Ogre::operator*", "group___math.html#gaa2866120e163a6ec8c8b03d2c9ca3951", null ],
    [ "Ogre::operator/", "group___math.html#ga6c940df49c0d61086dfe8525247a15ab", null ],
    [ "Ogre::operator*", "group___math.html#ga98a0c74584c55abd8651c0e87321a485", null ],
    [ "Ogre::operator/", "group___math.html#ga5ec05237e1f0696cbd0f50393e4aea0e", null ],
    [ "Ogre::operator*", "group___math.html#ga4194c1302dc1f5f13904688d5aa0bc1c", null ],
    [ "Ogre::operator*", "group___math.html#ga8283a37796cfb2426008099ba8a46e5f", null ],
    [ "Ogre::operator+", "group___math.html#gadd40f27f78ed1fe8e59df586b53be488", null ],
    [ "Ogre::operator-", "group___math.html#ga7c6c12700fc4b4d2d5947166ef459ae3", null ],
    [ "Ogre::operator*", "group___math.html#ga4ad543ded2a895ca3cb655acde809d6f", null ],
    [ "Ogre::operator*", "group___math.html#ga0fec6369363b2abbb7a66f363c25c765", null ],
    [ "Ogre::operator*", "group___math.html#ga15b5572666ec9a5a8c199d5289cd93bc", null ],
    [ "Ogre::operator*", "group___math.html#ga74f8fe372c36a629f723be7ad92b9573", null ],
    [ "Ogre::operator*", "group___math.html#ga3edf0891dcf445e20821a0504f53b5c4", null ],
    [ "Ogre::operator*", "group___math.html#gab98d9fe8e0bd1f28f9fed1009cd745dd", null ],
    [ "Ogre::rawOffsetPointer", "group___math.html#gaab35701a51537a7a1591982f4ca68ec9", null ],
    [ "Ogre::rawOffsetPointer", "group___math.html#gabc626df0e0e3cd90836235d97a2b90e9", null ],
    [ "Ogre::advanceRawPointer", "group___math.html#ga088106a9fc8539d9e0912c04a11f4ee6", null ],
    [ "Ogre::advanceRawPointer", "group___math.html#ga11dd7b55041c012f5d6e82d98d39cce1", null ],
    [ "Ogre::operator*", "group___math.html#ga2a819ee09ac0c63510f0079ba2bf2a3f", null ],
    [ "Ogre::Radian::Radian", "group___math.html#gae928a6c0bafde7b018e386ed94d76a84", null ],
    [ "Ogre::Radian::operator=", "group___math.html#gafab8ce89cde3034f3cc5c2537d5ea6fd", null ],
    [ "Ogre::Radian::operator+", "group___math.html#ga6aee68f4913cf646f4fa3c046a18ee60", null ],
    [ "Ogre::Radian::operator+=", "group___math.html#gaed5147935125e28f53cb19d70055bc88", null ],
    [ "Ogre::Radian::operator-", "group___math.html#ga05fd614aac352a71e17d8eb559578d7b", null ],
    [ "Ogre::Radian::operator-=", "group___math.html#ga223a82b9ff74351959eee91a335e7cdb", null ],
    [ "Ogre::Radian::valueDegrees", "group___math.html#gaac273cad14f6c100d692d7235919fe7f", null ],
    [ "Ogre::Radian::valueAngleUnits", "group___math.html#gae0e1b281e33d85e3364aeaa49c8ef2f5", null ],
    [ "Ogre::Degree::valueRadians", "group___math.html#ga01235157bea1375e48ed73634a6f9a18", null ],
    [ "Ogre::Degree::valueAngleUnits", "group___math.html#ga1fd64f1fc097bf4724b4713ff76cdfcd", null ],
    [ "Ogre::Angle::operator Radian", "group___math.html#gaf5f6b1190c20ab261874497f6bbb7dfd", null ],
    [ "Ogre::Angle::operator Degree", "group___math.html#ga166c0b2a2264eac93345461f93005b6e", null ],
    [ "Ogre::Math::lookRotation", "group___math.html#gae40391520c06bafb34a8647931fab8e1", null ],
    [ "Ogre::TransformBaseReal::transpose", "group___math.html#gaebc7c568cc1d6f13405a756be1af73fa", null ],
    [ "Ogre::Math::intersects", "group___math.html#gab3e9b9df69bd3255f3b64254e66c3321", null ],
    [ "Ogre::Math::intersects", "group___math.html#gafc5955de7b6ba0dfa860cc751c6321db", null ],
    [ "Ogre::Math::intersects", "group___math.html#ga64ed9272da4fcaccd8b1009a31358c61", null ],
    [ "Ogre::Math::intersects", "group___math.html#ga04786a5e338650d6eafc987b394d221c", null ],
    [ "Ogre::VectorBase< 2, Real >::midPoint", "group___math.html#ga4345346666fd54473efb51a8d194f5e0", null ],
    [ "Ogre::VectorBase< 2, Real >::randomDeviant", "group___math.html#gaba43517feb82c40ccf1cc571f519866c", null ],
    [ "Ogre::VectorBase< 2, Real >::angleTo", "group___math.html#ga7a92915df275eae8161441024d88c815", null ],
    [ "Ogre::VectorBase< 2, Real >::perpendicular", "group___math.html#ga00e57f3eda32e31277c439e6a9c929a1", null ],
    [ "Ogre::VectorBase< 3, Real >::perpendicular", "group___math.html#ga5b50a2b2697ec1ac684d66af82a03296", null ],
    [ "Ogre::VectorBase< 3, Real >::crossProduct", "group___math.html#gafe9157bbe30e69645edd5c3eddea141f", null ],
    [ "Ogre::VectorBase< 3, Real >::midPoint", "group___math.html#ga929562516cfb30c38030d9df84945bf3", null ],
    [ "Ogre::VectorBase< 3, Real >::randomDeviant", "group___math.html#ga4f54a2dd6b60dd327fcc8347fc4d853d", null ],
    [ "Ogre::VectorBase< 3, Real >::getRotationTo", "group___math.html#gac6ef79da21101ef5a671b0473b849bc3", null ],
    [ "Ogre::VectorBase< 3, Real >::positionCloses", "group___math.html#ga24dd46458beb0ea8175bfbf916f09e47", null ],
    [ "Ogre::VectorBase< 3, Real >::directionEquals", "group___math.html#gad67db81d99c63e2483ff8bc314bfd36c", null ],
    [ "Ogre::VectorBase< 3, Real >::primaryAxis", "group___math.html#gad52e72c687842e8475a5f24cde8cd858", null ],
    [ "Ogre::Math::calculateBasicFaceNormal", "group___math.html#ga813d02a0ee4c69dab452767fba1cef8a", null ],
    [ "Ogre::Math::calculateFaceNormal", "group___math.html#gae5ba1fde5b6a0056fd637d4e6b781a2a", null ],
    [ "Ogre::Math::calculateBasicFaceNormalWithoutNormalize", "group___math.html#gabcc5bd946f4c1fb73b851493e17b11b3", null ],
    [ "Ogre::Math::calculateFaceNormalWithoutNormalize", "group___math.html#gabc24b5e11a3a613f60dc44f6056dc61c", null ]
];